/* eslint-disable sort-exports/sort-exports */
/** For `EntityType.PLAYER` (1). */
export var PlayerVariant;
(function (PlayerVariant) {
    PlayerVariant[PlayerVariant["PLAYER"] = 0] = "PLAYER";
    PlayerVariant[PlayerVariant["COOP_BABY"] = 1] = "COOP_BABY";
})(PlayerVariant || (PlayerVariant = {}));
/**
 * For `EntityType.TEAR` (2).
 *
 * Generally, the `TearVariant` affects the graphics of the tear, while the `TearFlag` affects the
 * gameplay mechanic. For example, the Euthanasia collectible grants a chance for needle tears that
 * explode. `TearVariant.NEEDLE` makes the tear look like a needle, and the exploding effect comes
 * from `TearFlag.NEEDLE`.
 *
 * However, there are some exceptions:
 * - `TearVariant.CHAOS_CARD` (9) - The variant grants the instant-kill property of the tear.
 * - `TearVariant.KEY_BLOOD` (44) - Sharp Key makes Isaac shoot key tears that deal extra damage.
 *   Both the graphical effect and the extra damage are granted by this variant.
 */
export var TearVariant;
(function (TearVariant) {
    TearVariant[TearVariant["BLUE"] = 0] = "BLUE";
    TearVariant[TearVariant["BLOOD"] = 1] = "BLOOD";
    TearVariant[TearVariant["TOOTH"] = 2] = "TOOTH";
    /** Used by Loadstone. */
    TearVariant[TearVariant["METALLIC"] = 3] = "METALLIC";
    TearVariant[TearVariant["BOBS_HEAD"] = 4] = "BOBS_HEAD";
    TearVariant[TearVariant["FIRE_MIND"] = 5] = "FIRE_MIND";
    TearVariant[TearVariant["DARK_MATTER"] = 6] = "DARK_MATTER";
    TearVariant[TearVariant["MYSTERIOUS"] = 7] = "MYSTERIOUS";
    TearVariant[TearVariant["SCHYTHE"] = 8] = "SCHYTHE";
    /** This variant has a non-cosmetic property; it grants the instant-kill property of the tear. */
    TearVariant[TearVariant["CHAOS_CARD"] = 9] = "CHAOS_CARD";
    TearVariant[TearVariant["LOST_CONTACT"] = 10] = "LOST_CONTACT";
    TearVariant[TearVariant["CUPID_BLUE"] = 11] = "CUPID_BLUE";
    TearVariant[TearVariant["CUPID_BLOOD"] = 12] = "CUPID_BLOOD";
    TearVariant[TearVariant["NAIL"] = 13] = "NAIL";
    TearVariant[TearVariant["PUPULA"] = 14] = "PUPULA";
    TearVariant[TearVariant["PUPULA_BLOOD"] = 15] = "PUPULA_BLOOD";
    TearVariant[TearVariant["GODS_FLESH"] = 16] = "GODS_FLESH";
    TearVariant[TearVariant["GODS_FLESH_BLOOD"] = 17] = "GODS_FLESH_BLOOD";
    TearVariant[TearVariant["DIAMOND"] = 18] = "DIAMOND";
    TearVariant[TearVariant["EXPLOSIVO"] = 19] = "EXPLOSIVO";
    TearVariant[TearVariant["COIN"] = 20] = "COIN";
    TearVariant[TearVariant["MULTIDIMENSIONAL"] = 21] = "MULTIDIMENSIONAL";
    TearVariant[TearVariant["STONE"] = 22] = "STONE";
    TearVariant[TearVariant["NAIL_BLOOD"] = 23] = "NAIL_BLOOD";
    TearVariant[TearVariant["GLAUCOMA"] = 24] = "GLAUCOMA";
    TearVariant[TearVariant["GLAUCOMA_BLOOD"] = 25] = "GLAUCOMA_BLOOD";
    TearVariant[TearVariant["BOOGER"] = 26] = "BOOGER";
    TearVariant[TearVariant["EGG"] = 27] = "EGG";
    TearVariant[TearVariant["RAZOR"] = 28] = "RAZOR";
    TearVariant[TearVariant["BONE"] = 29] = "BONE";
    TearVariant[TearVariant["BLACK_TOOTH"] = 30] = "BLACK_TOOTH";
    /** Used by Euthanasia. */
    TearVariant[TearVariant["NEEDLE"] = 31] = "NEEDLE";
    TearVariant[TearVariant["BELIAL"] = 32] = "BELIAL";
    TearVariant[TearVariant["EYE"] = 33] = "EYE";
    TearVariant[TearVariant["EYE_BLOOD"] = 34] = "EYE_BLOOD";
    TearVariant[TearVariant["BALLOON"] = 35] = "BALLOON";
    TearVariant[TearVariant["HUNGRY"] = 36] = "HUNGRY";
    TearVariant[TearVariant["BALLOON_BRIMSTONE"] = 37] = "BALLOON_BRIMSTONE";
    TearVariant[TearVariant["BALLOON_BOMB"] = 38] = "BALLOON_BOMB";
    TearVariant[TearVariant["FIST"] = 39] = "FIST";
    /** Used by Mom's Bracelet. */
    TearVariant[TearVariant["GRID_ENTITY"] = 40] = "GRID_ENTITY";
    TearVariant[TearVariant["ICE"] = 41] = "ICE";
    TearVariant[TearVariant["ROCK"] = 42] = "ROCK";
    TearVariant[TearVariant["KEY"] = 43] = "KEY";
    /**
     * Used by Sharp Key. Both the graphical effect and the extra damage are granted by this variant.
     */
    TearVariant[TearVariant["KEY_BLOOD"] = 44] = "KEY_BLOOD";
    TearVariant[TearVariant["ERASER"] = 45] = "ERASER";
    TearVariant[TearVariant["FIRE"] = 46] = "FIRE";
    TearVariant[TearVariant["SWORD_BEAM"] = 47] = "SWORD_BEAM";
    TearVariant[TearVariant["SPORE"] = 48] = "SPORE";
    TearVariant[TearVariant["TECH_SWORD_BEAM"] = 49] = "TECH_SWORD_BEAM";
    TearVariant[TearVariant["FETUS"] = 50] = "FETUS";
})(TearVariant || (TearVariant = {}));
/** For `EntityType.FAMILIAR` (3). */
export var FamiliarVariant;
(function (FamiliarVariant) {
    FamiliarVariant[FamiliarVariant["FAMILIAR_NULL"] = 0] = "FAMILIAR_NULL";
    FamiliarVariant[FamiliarVariant["BROTHER_BOBBY"] = 1] = "BROTHER_BOBBY";
    FamiliarVariant[FamiliarVariant["DEMON_BABY"] = 2] = "DEMON_BABY";
    FamiliarVariant[FamiliarVariant["LITTLE_CHUBBY"] = 3] = "LITTLE_CHUBBY";
    FamiliarVariant[FamiliarVariant["LITTLE_GISH"] = 4] = "LITTLE_GISH";
    FamiliarVariant[FamiliarVariant["LITTLE_STEVEN"] = 5] = "LITTLE_STEVEN";
    FamiliarVariant[FamiliarVariant["ROBO_BABY"] = 6] = "ROBO_BABY";
    FamiliarVariant[FamiliarVariant["SISTER_MAGGY"] = 7] = "SISTER_MAGGY";
    FamiliarVariant[FamiliarVariant["ABEL"] = 8] = "ABEL";
    FamiliarVariant[FamiliarVariant["GHOST_BABY"] = 9] = "GHOST_BABY";
    FamiliarVariant[FamiliarVariant["HARLEQUIN_BABY"] = 10] = "HARLEQUIN_BABY";
    FamiliarVariant[FamiliarVariant["RAINBOW_BABY"] = 11] = "RAINBOW_BABY";
    FamiliarVariant[FamiliarVariant["ISAACS_HEAD"] = 12] = "ISAACS_HEAD";
    FamiliarVariant[FamiliarVariant["BLUE_BABY_SOUL"] = 13] = "BLUE_BABY_SOUL";
    FamiliarVariant[FamiliarVariant["DEAD_BIRD"] = 14] = "DEAD_BIRD";
    FamiliarVariant[FamiliarVariant["EVES_BIRD_FOOT"] = 15] = "EVES_BIRD_FOOT";
    FamiliarVariant[FamiliarVariant["DADDY_LONGLEGS"] = 16] = "DADDY_LONGLEGS";
    FamiliarVariant[FamiliarVariant["PEEPER"] = 17] = "PEEPER";
    FamiliarVariant[FamiliarVariant["BOMB_BAG"] = 20] = "BOMB_BAG";
    FamiliarVariant[FamiliarVariant["SACK_OF_PENNIES"] = 21] = "SACK_OF_PENNIES";
    FamiliarVariant[FamiliarVariant["LITTLE_CHAD"] = 22] = "LITTLE_CHAD";
    FamiliarVariant[FamiliarVariant["RELIC"] = 23] = "RELIC";
    FamiliarVariant[FamiliarVariant["BUM_FRIEND"] = 24] = "BUM_FRIEND";
    FamiliarVariant[FamiliarVariant["HOLY_WATER"] = 25] = "HOLY_WATER";
    FamiliarVariant[FamiliarVariant["KEY_PIECE_1"] = 26] = "KEY_PIECE_1";
    FamiliarVariant[FamiliarVariant["KEY_PIECE_2"] = 27] = "KEY_PIECE_2";
    FamiliarVariant[FamiliarVariant["KEY_FULL"] = 28] = "KEY_FULL";
    FamiliarVariant[FamiliarVariant["FOREVER_ALONE"] = 30] = "FOREVER_ALONE";
    FamiliarVariant[FamiliarVariant["DISTANT_ADMIRATION"] = 31] = "DISTANT_ADMIRATION";
    FamiliarVariant[FamiliarVariant["GUARDIAN_ANGEL"] = 32] = "GUARDIAN_ANGEL";
    FamiliarVariant[FamiliarVariant["FLY_ORBITAL"] = 33] = "FLY_ORBITAL";
    FamiliarVariant[FamiliarVariant["SACRIFICIAL_DAGGER"] = 35] = "SACRIFICIAL_DAGGER";
    FamiliarVariant[FamiliarVariant["DEAD_CAT"] = 40] = "DEAD_CAT";
    FamiliarVariant[FamiliarVariant["ONE_UP"] = 41] = "ONE_UP";
    FamiliarVariant[FamiliarVariant["GUPPYS_HAIRBALL"] = 42] = "GUPPYS_HAIRBALL";
    FamiliarVariant[FamiliarVariant["BLUE_FLY"] = 43] = "BLUE_FLY";
    FamiliarVariant[FamiliarVariant["CUBE_OF_MEAT_1"] = 44] = "CUBE_OF_MEAT_1";
    FamiliarVariant[FamiliarVariant["CUBE_OF_MEAT_2"] = 45] = "CUBE_OF_MEAT_2";
    FamiliarVariant[FamiliarVariant["CUBE_OF_MEAT_3"] = 46] = "CUBE_OF_MEAT_3";
    FamiliarVariant[FamiliarVariant["CUBE_OF_MEAT_4"] = 47] = "CUBE_OF_MEAT_4";
    FamiliarVariant[FamiliarVariant["ISAACS_BODY"] = 48] = "ISAACS_BODY";
    FamiliarVariant[FamiliarVariant["SMART_FLY"] = 50] = "SMART_FLY";
    FamiliarVariant[FamiliarVariant["DRY_BABY"] = 51] = "DRY_BABY";
    FamiliarVariant[FamiliarVariant["JUICY_SACK"] = 52] = "JUICY_SACK";
    FamiliarVariant[FamiliarVariant["ROBO_BABY_2"] = 53] = "ROBO_BABY_2";
    FamiliarVariant[FamiliarVariant["ROTTEN_BABY"] = 54] = "ROTTEN_BABY";
    FamiliarVariant[FamiliarVariant["HEADLESS_BABY"] = 55] = "HEADLESS_BABY";
    FamiliarVariant[FamiliarVariant["LEECH"] = 56] = "LEECH";
    FamiliarVariant[FamiliarVariant["MYSTERY_SACK"] = 57] = "MYSTERY_SACK";
    FamiliarVariant[FamiliarVariant["BBF"] = 58] = "BBF";
    FamiliarVariant[FamiliarVariant["BOBS_BRAIN"] = 59] = "BOBS_BRAIN";
    FamiliarVariant[FamiliarVariant["BEST_BUD"] = 60] = "BEST_BUD";
    FamiliarVariant[FamiliarVariant["LIL_BRIMSTONE"] = 61] = "LIL_BRIMSTONE";
    FamiliarVariant[FamiliarVariant["ISAACS_HEART"] = 62] = "ISAACS_HEART";
    FamiliarVariant[FamiliarVariant["LIL_HAUNT"] = 63] = "LIL_HAUNT";
    FamiliarVariant[FamiliarVariant["DARK_BUM"] = 64] = "DARK_BUM";
    FamiliarVariant[FamiliarVariant["BIG_FAN"] = 65] = "BIG_FAN";
    FamiliarVariant[FamiliarVariant["SISSY_LONGLEGS"] = 66] = "SISSY_LONGLEGS";
    FamiliarVariant[FamiliarVariant["PUNCHING_BAG"] = 67] = "PUNCHING_BAG";
    FamiliarVariant[FamiliarVariant["GUILLOTINE"] = 68] = "GUILLOTINE";
    FamiliarVariant[FamiliarVariant["BALL_OF_BANDAGES_1"] = 69] = "BALL_OF_BANDAGES_1";
    FamiliarVariant[FamiliarVariant["BALL_OF_BANDAGES_2"] = 70] = "BALL_OF_BANDAGES_2";
    FamiliarVariant[FamiliarVariant["BALL_OF_BANDAGES_3"] = 71] = "BALL_OF_BANDAGES_3";
    FamiliarVariant[FamiliarVariant["BALL_OF_BANDAGES_4"] = 72] = "BALL_OF_BANDAGES_4";
    FamiliarVariant[FamiliarVariant["BLUE_SPIDER"] = 73] = "BLUE_SPIDER";
    FamiliarVariant[FamiliarVariant["MONGO_BABY"] = 74] = "MONGO_BABY";
    FamiliarVariant[FamiliarVariant["SAMSONS_CHAINS"] = 75] = "SAMSONS_CHAINS";
    FamiliarVariant[FamiliarVariant["CAINS_OTHER_EYE"] = 76] = "CAINS_OTHER_EYE";
    FamiliarVariant[FamiliarVariant["BLUE_BABYS_ONLY_FRIEND"] = 77] = "BLUE_BABYS_ONLY_FRIEND";
    FamiliarVariant[FamiliarVariant["SCISSORS"] = 78] = "SCISSORS";
    FamiliarVariant[FamiliarVariant["GEMINI"] = 79] = "GEMINI";
    FamiliarVariant[FamiliarVariant["INCUBUS"] = 80] = "INCUBUS";
    FamiliarVariant[FamiliarVariant["FATES_REWARD"] = 81] = "FATES_REWARD";
    FamiliarVariant[FamiliarVariant["LIL_CHEST"] = 82] = "LIL_CHEST";
    FamiliarVariant[FamiliarVariant["SWORN_PROTECTOR"] = 83] = "SWORN_PROTECTOR";
    FamiliarVariant[FamiliarVariant["FRIEND_ZONE"] = 84] = "FRIEND_ZONE";
    FamiliarVariant[FamiliarVariant["LOST_FLY"] = 85] = "LOST_FLY";
    FamiliarVariant[FamiliarVariant["CHARGED_BABY"] = 86] = "CHARGED_BABY";
    FamiliarVariant[FamiliarVariant["LIL_GURDY"] = 87] = "LIL_GURDY";
    FamiliarVariant[FamiliarVariant["BUMBO"] = 88] = "BUMBO";
    FamiliarVariant[FamiliarVariant["CENSER"] = 89] = "CENSER";
    FamiliarVariant[FamiliarVariant["KEY_BUM"] = 90] = "KEY_BUM";
    FamiliarVariant[FamiliarVariant["RUNE_BAG"] = 91] = "RUNE_BAG";
    FamiliarVariant[FamiliarVariant["SERAPHIM"] = 92] = "SERAPHIM";
    FamiliarVariant[FamiliarVariant["GB_BUG"] = 93] = "GB_BUG";
    FamiliarVariant[FamiliarVariant["SPIDER_MOD"] = 94] = "SPIDER_MOD";
    FamiliarVariant[FamiliarVariant["FARTING_BABY"] = 95] = "FARTING_BABY";
    FamiliarVariant[FamiliarVariant["SUCCUBUS"] = 96] = "SUCCUBUS";
    FamiliarVariant[FamiliarVariant["LIL_LOKI"] = 97] = "LIL_LOKI";
    FamiliarVariant[FamiliarVariant["OBSESSED_FAN"] = 98] = "OBSESSED_FAN";
    FamiliarVariant[FamiliarVariant["PAPA_FLY"] = 99] = "PAPA_FLY";
    FamiliarVariant[FamiliarVariant["MILK"] = 100] = "MILK";
    FamiliarVariant[FamiliarVariant["MULTIDIMENSIONAL_BABY"] = 101] = "MULTIDIMENSIONAL_BABY";
    FamiliarVariant[FamiliarVariant["SUPER_BUM"] = 102] = "SUPER_BUM";
    FamiliarVariant[FamiliarVariant["TONSIL"] = 103] = "TONSIL";
    FamiliarVariant[FamiliarVariant["BIG_CHUBBY"] = 104] = "BIG_CHUBBY";
    FamiliarVariant[FamiliarVariant["DEPRESSION"] = 105] = "DEPRESSION";
    FamiliarVariant[FamiliarVariant["SHADE"] = 106] = "SHADE";
    FamiliarVariant[FamiliarVariant["HUSHY"] = 107] = "HUSHY";
    FamiliarVariant[FamiliarVariant["LIL_MONSTRO"] = 108] = "LIL_MONSTRO";
    FamiliarVariant[FamiliarVariant["KING_BABY"] = 109] = "KING_BABY";
    FamiliarVariant[FamiliarVariant["FINGER"] = 110] = "FINGER";
    FamiliarVariant[FamiliarVariant["YO_LISTEN"] = 111] = "YO_LISTEN";
    FamiliarVariant[FamiliarVariant["ACID_BABY"] = 112] = "ACID_BABY";
    FamiliarVariant[FamiliarVariant["SPIDER_BABY"] = 113] = "SPIDER_BABY";
    FamiliarVariant[FamiliarVariant["SACK_OF_SACKS"] = 114] = "SACK_OF_SACKS";
    FamiliarVariant[FamiliarVariant["BROWN_NUGGET_POOTER"] = 115] = "BROWN_NUGGET_POOTER";
    FamiliarVariant[FamiliarVariant["BLOODSHOT_EYE"] = 116] = "BLOODSHOT_EYE";
    FamiliarVariant[FamiliarVariant["MOMS_RAZOR"] = 117] = "MOMS_RAZOR";
    FamiliarVariant[FamiliarVariant["ANGRY_FLY"] = 118] = "ANGRY_FLY";
    FamiliarVariant[FamiliarVariant["BUDDY_IN_A_BOX"] = 119] = "BUDDY_IN_A_BOX";
    FamiliarVariant[FamiliarVariant["SPRINKLER"] = 120] = "SPRINKLER";
    FamiliarVariant[FamiliarVariant["LEPROSY"] = 121] = "LEPROSY";
    FamiliarVariant[FamiliarVariant["LIL_HARBINGERS"] = 122] = "LIL_HARBINGERS";
    FamiliarVariant[FamiliarVariant["ANGELIC_PRISM"] = 123] = "ANGELIC_PRISM";
    FamiliarVariant[FamiliarVariant["MYSTERY_EGG"] = 124] = "MYSTERY_EGG";
    FamiliarVariant[FamiliarVariant["LIL_SPEWER"] = 125] = "LIL_SPEWER";
    FamiliarVariant[FamiliarVariant["SLIPPED_RIB"] = 126] = "SLIPPED_RIB";
    FamiliarVariant[FamiliarVariant["POINTY_RIB"] = 127] = "POINTY_RIB";
    FamiliarVariant[FamiliarVariant["BONE_ORBITAL"] = 128] = "BONE_ORBITAL";
    FamiliarVariant[FamiliarVariant["HALLOWED_GROUND"] = 129] = "HALLOWED_GROUND";
    FamiliarVariant[FamiliarVariant["JAW_BONE"] = 130] = "JAW_BONE";
    FamiliarVariant[FamiliarVariant["INTRUDER"] = 200] = "INTRUDER";
    FamiliarVariant[FamiliarVariant["DIP"] = 201] = "DIP";
    FamiliarVariant[FamiliarVariant["DAMOCLES"] = 202] = "DAMOCLES";
    FamiliarVariant[FamiliarVariant["BLOOD_OATH"] = 203] = "BLOOD_OATH";
    FamiliarVariant[FamiliarVariant["PSY_FLY"] = 204] = "PSY_FLY";
    FamiliarVariant[FamiliarVariant["MENORAH"] = 205] = "MENORAH";
    FamiliarVariant[FamiliarVariant["WISP"] = 206] = "WISP";
    FamiliarVariant[FamiliarVariant["PEEPER_2"] = 207] = "PEEPER_2";
    FamiliarVariant[FamiliarVariant["BOILED_BABY"] = 208] = "BOILED_BABY";
    FamiliarVariant[FamiliarVariant["FREEZER_BABY"] = 209] = "FREEZER_BABY";
    FamiliarVariant[FamiliarVariant["BIRD_CAGE"] = 210] = "BIRD_CAGE";
    FamiliarVariant[FamiliarVariant["LOST_SOUL"] = 211] = "LOST_SOUL";
    FamiliarVariant[FamiliarVariant["LIL_DUMPY"] = 212] = "LIL_DUMPY";
    FamiliarVariant[FamiliarVariant["KNIFE_PIECE_1"] = 213] = "KNIFE_PIECE_1";
    FamiliarVariant[FamiliarVariant["KNIFE_PIECE_2"] = 214] = "KNIFE_PIECE_2";
    FamiliarVariant[FamiliarVariant["TINYTOMA"] = 216] = "TINYTOMA";
    FamiliarVariant[FamiliarVariant["TINYTOMA_2"] = 217] = "TINYTOMA_2";
    FamiliarVariant[FamiliarVariant["BOT_FLY"] = 218] = "BOT_FLY";
    FamiliarVariant[FamiliarVariant["SIREN_MINION"] = 220] = "SIREN_MINION";
    FamiliarVariant[FamiliarVariant["PASCHAL_CANDLE"] = 221] = "PASCHAL_CANDLE";
    FamiliarVariant[FamiliarVariant["STITCHES"] = 222] = "STITCHES";
    FamiliarVariant[FamiliarVariant["KNIFE_FULL"] = 223] = "KNIFE_FULL";
    FamiliarVariant[FamiliarVariant["BABY_PLUM"] = 224] = "BABY_PLUM";
    FamiliarVariant[FamiliarVariant["FRUITY_PLUM"] = 225] = "FRUITY_PLUM";
    FamiliarVariant[FamiliarVariant["SPIN_TO_WIN"] = 226] = "SPIN_TO_WIN";
    FamiliarVariant[FamiliarVariant["MINISAAC"] = 228] = "MINISAAC";
    FamiliarVariant[FamiliarVariant["SWARM_FLY_ORBITAL"] = 229] = "SWARM_FLY_ORBITAL";
    FamiliarVariant[FamiliarVariant["LIL_ABADDON"] = 230] = "LIL_ABADDON";
    FamiliarVariant[FamiliarVariant["ABYSS_LOCUST"] = 231] = "ABYSS_LOCUST";
    FamiliarVariant[FamiliarVariant["LIL_PORTAL"] = 232] = "LIL_PORTAL";
    FamiliarVariant[FamiliarVariant["WORM_FRIEND"] = 233] = "WORM_FRIEND";
    FamiliarVariant[FamiliarVariant["BONE_SPUR"] = 234] = "BONE_SPUR";
    FamiliarVariant[FamiliarVariant["TWISTED_BABY"] = 235] = "TWISTED_BABY";
    FamiliarVariant[FamiliarVariant["STAR_OF_BETHLEHEM"] = 236] = "STAR_OF_BETHLEHEM";
    FamiliarVariant[FamiliarVariant["ITEM_WISP"] = 237] = "ITEM_WISP";
    FamiliarVariant[FamiliarVariant["BLOOD_BABY"] = 238] = "BLOOD_BABY";
    FamiliarVariant[FamiliarVariant["CUBE_BABY"] = 239] = "CUBE_BABY";
    /** Produced from the Gello collectible. */
    FamiliarVariant[FamiliarVariant["UMBILICAL_BABY"] = 240] = "UMBILICAL_BABY";
    FamiliarVariant[FamiliarVariant["BLOOD_PUPPY"] = 241] = "BLOOD_PUPPY";
    FamiliarVariant[FamiliarVariant["VANISHING_TWIN"] = 242] = "VANISHING_TWIN";
    FamiliarVariant[FamiliarVariant["DECAP_ATTACK"] = 243] = "DECAP_ATTACK";
    FamiliarVariant[FamiliarVariant["FORGOTTEN_BODY"] = 900] = "FORGOTTEN_BODY";
})(FamiliarVariant || (FamiliarVariant = {}));
/** For `EntityType.BOMB` (4). */
export var BombVariant;
(function (BombVariant) {
    BombVariant[BombVariant["NORMAL"] = 0] = "NORMAL";
    /** Mr. Boom bombs. */
    BombVariant[BombVariant["BIG"] = 1] = "BIG";
    /** The decoy object from Best Friend. */
    BombVariant[BombVariant["DECOY"] = 2] = "DECOY";
    BombVariant[BombVariant["TROLL"] = 3] = "TROLL";
    BombVariant[BombVariant["MEGA_TROLL"] = 4] = "MEGA_TROLL";
    /** Bob's Curse bombs. */
    BombVariant[BombVariant["POISON"] = 5] = "POISON";
    /** Bomb's Curse + Mr. Mega bombs. */
    BombVariant[BombVariant["POISON_BIG"] = 6] = "POISON_BIG";
    BombVariant[BombVariant["SAD"] = 7] = "SAD";
    BombVariant[BombVariant["HOT"] = 8] = "HOT";
    BombVariant[BombVariant["BUTT"] = 9] = "BUTT";
    BombVariant[BombVariant["MR_MEGA"] = 10] = "MR_MEGA";
    BombVariant[BombVariant["BOBBY"] = 11] = "BOBBY";
    BombVariant[BombVariant["GLITTER"] = 12] = "GLITTER";
    /** The red bombs that are created on certain Repentance floors. */
    BombVariant[BombVariant["THROWABLE"] = 13] = "THROWABLE";
    /** The small bombs from Scatter Bombs. */
    BombVariant[BombVariant["SMALL"] = 14] = "SMALL";
    BombVariant[BombVariant["BRIMSTONE"] = 15] = "BRIMSTONE";
    /**
     * A special bomb type rarely thrown by Hornfel. This looks very similar to the type of bombs that
     * result from the player having Sad Bombs + Blood Bombs, but this has a slightly different mouth.
     */
    BombVariant[BombVariant["SAD_BLOOD"] = 16] = "SAD_BLOOD";
    BombVariant[BombVariant["GIGA"] = 17] = "GIGA";
    BombVariant[BombVariant["GOLDEN_TROLL"] = 18] = "GOLDEN_TROLL";
    BombVariant[BombVariant["ROCKET"] = 19] = "ROCKET";
    BombVariant[BombVariant["ROCKET_GIGA"] = 20] = "ROCKET_GIGA";
})(BombVariant || (BombVariant = {}));
/** For `EntityType.PICKUP` (5). */
export var PickupVariant;
(function (PickupVariant) {
    PickupVariant[PickupVariant["NULL"] = 0] = "NULL";
    PickupVariant[PickupVariant["HEART"] = 10] = "HEART";
    PickupVariant[PickupVariant["COIN"] = 20] = "COIN";
    PickupVariant[PickupVariant["KEY"] = 30] = "KEY";
    PickupVariant[PickupVariant["BOMB"] = 40] = "BOMB";
    PickupVariant[PickupVariant["THROWABLE_BOMB"] = 41] = "THROWABLE_BOMB";
    /** The poop bombs that only spawn when the player is Tainted Blue Baby. */
    PickupVariant[PickupVariant["POOP"] = 42] = "POOP";
    PickupVariant[PickupVariant["CHEST"] = 50] = "CHEST";
    PickupVariant[PickupVariant["BOMB_CHEST"] = 51] = "BOMB_CHEST";
    PickupVariant[PickupVariant["SPIKED_CHEST"] = 52] = "SPIKED_CHEST";
    PickupVariant[PickupVariant["ETERNAL_CHEST"] = 53] = "ETERNAL_CHEST";
    PickupVariant[PickupVariant["MIMIC_CHEST"] = 54] = "MIMIC_CHEST";
    PickupVariant[PickupVariant["OLD_CHEST"] = 55] = "OLD_CHEST";
    PickupVariant[PickupVariant["WOODEN_CHEST"] = 56] = "WOODEN_CHEST";
    PickupVariant[PickupVariant["MEGA_CHEST"] = 57] = "MEGA_CHEST";
    PickupVariant[PickupVariant["HAUNTED_CHEST"] = 58] = "HAUNTED_CHEST";
    /** The gold chest that requires a key to open. */
    PickupVariant[PickupVariant["LOCKED_CHEST"] = 60] = "LOCKED_CHEST";
    PickupVariant[PickupVariant["SACK"] = 69] = "SACK";
    PickupVariant[PickupVariant["PILL"] = 70] = "PILL";
    PickupVariant[PickupVariant["LIL_BATTERY"] = 90] = "LIL_BATTERY";
    PickupVariant[PickupVariant["COLLECTIBLE"] = 100] = "COLLECTIBLE";
    PickupVariant[PickupVariant["BROKEN_SHOVEL"] = 110] = "BROKEN_SHOVEL";
    PickupVariant[PickupVariant["SHOP_ITEM"] = 150] = "SHOP_ITEM";
    PickupVariant[PickupVariant["CARD"] = 300] = "CARD";
    PickupVariant[PickupVariant["BIG_CHEST"] = 340] = "BIG_CHEST";
    PickupVariant[PickupVariant["TRINKET"] = 350] = "TRINKET";
    PickupVariant[PickupVariant["RED_CHEST"] = 360] = "RED_CHEST";
    PickupVariant[PickupVariant["TROPHY"] = 370] = "TROPHY";
    PickupVariant[PickupVariant["BED"] = 380] = "BED";
    PickupVariant[PickupVariant["MOMS_CHEST"] = 390] = "MOMS_CHEST";
})(PickupVariant || (PickupVariant = {}));
/** For `EntityType.SLOT` (6). */
export var SlotVariant;
(function (SlotVariant) {
    SlotVariant[SlotVariant["SLOT_MACHINE"] = 1] = "SLOT_MACHINE";
    SlotVariant[SlotVariant["BLOOD_DONATION_MACHINE"] = 2] = "BLOOD_DONATION_MACHINE";
    SlotVariant[SlotVariant["FORTUNE_TELLING_MACHINE"] = 3] = "FORTUNE_TELLING_MACHINE";
    SlotVariant[SlotVariant["BEGGAR"] = 4] = "BEGGAR";
    SlotVariant[SlotVariant["DEVIL_BEGGAR"] = 5] = "DEVIL_BEGGAR";
    SlotVariant[SlotVariant["SHELL_GAME"] = 6] = "SHELL_GAME";
    SlotVariant[SlotVariant["KEY_MASTER"] = 7] = "KEY_MASTER";
    SlotVariant[SlotVariant["DONATION_MACHINE"] = 8] = "DONATION_MACHINE";
    SlotVariant[SlotVariant["BOMB_BUM"] = 9] = "BOMB_BUM";
    SlotVariant[SlotVariant["SHOP_RESTOCK_MACHINE"] = 10] = "SHOP_RESTOCK_MACHINE";
    SlotVariant[SlotVariant["GREED_DONATION_MACHINE"] = 11] = "GREED_DONATION_MACHINE";
    SlotVariant[SlotVariant["MOMS_DRESSING_TABLE"] = 12] = "MOMS_DRESSING_TABLE";
    SlotVariant[SlotVariant["BATTERY_BUM"] = 13] = "BATTERY_BUM";
    SlotVariant[SlotVariant["ISAAC_SECRET"] = 14] = "ISAAC_SECRET";
    SlotVariant[SlotVariant["HELL_GAME"] = 15] = "HELL_GAME";
    SlotVariant[SlotVariant["CRANE_GAME"] = 16] = "CRANE_GAME";
    SlotVariant[SlotVariant["CONFESSIONAL"] = 17] = "CONFESSIONAL";
    SlotVariant[SlotVariant["ROTTEN_BEGGAR"] = 18] = "ROTTEN_BEGGAR";
})(SlotVariant || (SlotVariant = {}));
/** For `EntityType.LASER` (7). */
export var LaserVariant;
(function (LaserVariant) {
    /** Used for Brimstone. */
    LaserVariant[LaserVariant["THICK_RED"] = 1] = "THICK_RED";
    /** Used for Technology. */
    LaserVariant[LaserVariant["THIN_RED"] = 2] = "THIN_RED";
    LaserVariant[LaserVariant["SHOOP_DA_WHOOP"] = 3] = "SHOOP_DA_WHOOP";
    /** Looks like a squiggly line. */
    LaserVariant[LaserVariant["PRIDE"] = 4] = "PRIDE";
    /** Used for Angel lasers. */
    LaserVariant[LaserVariant["LIGHT_BEAM"] = 5] = "LIGHT_BEAM";
    /** Used for Mega Blast. */
    LaserVariant[LaserVariant["GIANT_RED"] = 6] = "GIANT_RED";
    LaserVariant[LaserVariant["TRACTOR_BEAM"] = 7] = "TRACTOR_BEAM";
    /** Used for Circle of Protection; looks like a thinner Angel laser. */
    LaserVariant[LaserVariant["LIGHT_RING"] = 8] = "LIGHT_RING";
    LaserVariant[LaserVariant["BRIMSTONE_TECHNOLOGY"] = 9] = "BRIMSTONE_TECHNOLOGY";
    LaserVariant[LaserVariant["ELECTRIC"] = 10] = "ELECTRIC";
    LaserVariant[LaserVariant["THICKER_RED"] = 11] = "THICKER_RED";
    LaserVariant[LaserVariant["THICK_BROWN"] = 12] = "THICK_BROWN";
    LaserVariant[LaserVariant["BEAST"] = 13] = "BEAST";
    LaserVariant[LaserVariant["THICKER_BRIMSTONE_TECHNOLOGY"] = 14] = "THICKER_BRIMSTONE_TECHNOLOGY";
    LaserVariant[LaserVariant["GIANT_BRIMSTONE_TECHNOLOGY"] = 15] = "GIANT_BRIMSTONE_TECHNOLOGY";
})(LaserVariant || (LaserVariant = {}));
/** For `EntityType.KNIFE` (8). */
export var KnifeVariant;
(function (KnifeVariant) {
    KnifeVariant[KnifeVariant["MOMS_KNIFE"] = 0] = "MOMS_KNIFE";
    KnifeVariant[KnifeVariant["BONE_CLUB"] = 1] = "BONE_CLUB";
    KnifeVariant[KnifeVariant["BONE_SCYTHE"] = 2] = "BONE_SCYTHE";
    KnifeVariant[KnifeVariant["DONKEY_JAWBONE"] = 3] = "DONKEY_JAWBONE";
    KnifeVariant[KnifeVariant["BAG_OF_CRAFTING"] = 4] = "BAG_OF_CRAFTING";
    KnifeVariant[KnifeVariant["SUMPTORIUM"] = 5] = "SUMPTORIUM";
    // - 6 is unused.
    // - 7 is unused.
    // - 8 is unused.
    KnifeVariant[KnifeVariant["NOTCHED_AXE"] = 9] = "NOTCHED_AXE";
    KnifeVariant[KnifeVariant["SPIRIT_SWORD"] = 10] = "SPIRIT_SWORD";
    KnifeVariant[KnifeVariant["TECH_SWORD"] = 11] = "TECH_SWORD";
})(KnifeVariant || (KnifeVariant = {}));
/** For `EntityType.PROJECTILE` (9). */
export var ProjectileVariant;
(function (ProjectileVariant) {
    ProjectileVariant[ProjectileVariant["NORMAL"] = 0] = "NORMAL";
    ProjectileVariant[ProjectileVariant["BONE"] = 1] = "BONE";
    ProjectileVariant[ProjectileVariant["FIRE"] = 2] = "FIRE";
    ProjectileVariant[ProjectileVariant["PUKE"] = 3] = "PUKE";
    ProjectileVariant[ProjectileVariant["TEAR"] = 4] = "TEAR";
    ProjectileVariant[ProjectileVariant["CORN"] = 5] = "CORN";
    ProjectileVariant[ProjectileVariant["HUSH"] = 6] = "HUSH";
    ProjectileVariant[ProjectileVariant["COIN"] = 7] = "COIN";
    ProjectileVariant[ProjectileVariant["GRID"] = 8] = "GRID";
    ProjectileVariant[ProjectileVariant["ROCK"] = 9] = "ROCK";
    ProjectileVariant[ProjectileVariant["RING"] = 10] = "RING";
    ProjectileVariant[ProjectileVariant["MEAT"] = 11] = "MEAT";
    ProjectileVariant[ProjectileVariant["FCUK"] = 12] = "FCUK";
    ProjectileVariant[ProjectileVariant["WING"] = 13] = "WING";
    ProjectileVariant[ProjectileVariant["LAVA"] = 14] = "LAVA";
    ProjectileVariant[ProjectileVariant["HEAD"] = 15] = "HEAD";
    ProjectileVariant[ProjectileVariant["PEEP"] = 16] = "PEEP";
})(ProjectileVariant || (ProjectileVariant = {}));
/** For `EntityType.GAPER` (10). */
export var GaperVariant;
(function (GaperVariant) {
    GaperVariant[GaperVariant["FROWNING_GAPER"] = 0] = "FROWNING_GAPER";
    GaperVariant[GaperVariant["GAPER"] = 1] = "GAPER";
    GaperVariant[GaperVariant["FLAMING_GAPER"] = 2] = "FLAMING_GAPER";
    GaperVariant[GaperVariant["ROTTEN_GAPER"] = 3] = "ROTTEN_GAPER";
})(GaperVariant || (GaperVariant = {}));
/** For `EntityType.GUSHER` (11). */
export var GusherVariant;
(function (GusherVariant) {
    GusherVariant[GusherVariant["GUSHER"] = 0] = "GUSHER";
    GusherVariant[GusherVariant["PACER"] = 1] = "PACER";
})(GusherVariant || (GusherVariant = {}));
/** For `EntityType.POOTER` (14). */
export var PooterVariant;
(function (PooterVariant) {
    PooterVariant[PooterVariant["POOTER"] = 0] = "POOTER";
    PooterVariant[PooterVariant["SUPER_POOTER"] = 1] = "SUPER_POOTER";
    PooterVariant[PooterVariant["TAINTED_POOTER"] = 2] = "TAINTED_POOTER";
})(PooterVariant || (PooterVariant = {}));
/** For `EntityType.CLOTTY` (15). */
export var ClottyVariant;
(function (ClottyVariant) {
    ClottyVariant[ClottyVariant["CLOTTY"] = 0] = "CLOTTY";
    ClottyVariant[ClottyVariant["CLOT"] = 1] = "CLOT";
    ClottyVariant[ClottyVariant["BLOB"] = 2] = "BLOB";
    ClottyVariant[ClottyVariant["GRILLED_CLOTTY"] = 3] = "GRILLED_CLOTTY";
})(ClottyVariant || (ClottyVariant = {}));
/** For `EntityType.MULLIGAN` (16). */
export var MulliganVariant;
(function (MulliganVariant) {
    MulliganVariant[MulliganVariant["MULLIGAN"] = 0] = "MULLIGAN";
    MulliganVariant[MulliganVariant["MULLIGOON"] = 1] = "MULLIGOON";
    MulliganVariant[MulliganVariant["MULLIBOOM"] = 2] = "MULLIBOOM";
})(MulliganVariant || (MulliganVariant = {}));
/** For `EntityType.SHOPKEEPER` (17). */
export var ShopkeeperVariant;
(function (ShopkeeperVariant) {
    ShopkeeperVariant[ShopkeeperVariant["SHOPKEEPER"] = 0] = "SHOPKEEPER";
    ShopkeeperVariant[ShopkeeperVariant["SECRET_ROOM_KEEPER"] = 1] = "SECRET_ROOM_KEEPER";
    ShopkeeperVariant[ShopkeeperVariant["ERROR_ROOM_KEEPER"] = 2] = "ERROR_ROOM_KEEPER";
    ShopkeeperVariant[ShopkeeperVariant["SPECIAL_SHOPKEEPER"] = 3] = "SPECIAL_SHOPKEEPER";
    ShopkeeperVariant[ShopkeeperVariant["SPECIAL_SECRET_ROOM_KEEPER"] = 4] = "SPECIAL_SECRET_ROOM_KEEPER";
})(ShopkeeperVariant || (ShopkeeperVariant = {}));
/** For `EntityType.LARRY_JR` (19). */
export var LarryJrVariant;
(function (LarryJrVariant) {
    LarryJrVariant[LarryJrVariant["LARRY_JR"] = 0] = "LARRY_JR";
    LarryJrVariant[LarryJrVariant["HOLLOW"] = 1] = "HOLLOW";
    LarryJrVariant[LarryJrVariant["TUFF_TWIN"] = 2] = "TUFF_TWIN";
    LarryJrVariant[LarryJrVariant["SHELL"] = 3] = "SHELL";
})(LarryJrVariant || (LarryJrVariant = {}));
/** For `EntityType.HIVE` (22). */
export var HiveVariant;
(function (HiveVariant) {
    HiveVariant[HiveVariant["HIVE"] = 0] = "HIVE";
    HiveVariant[HiveVariant["DROWNED_HIVE"] = 1] = "DROWNED_HIVE";
    HiveVariant[HiveVariant["HOLY_MULLIGAN"] = 2] = "HOLY_MULLIGAN";
    HiveVariant[HiveVariant["TAINTED_MULLIGAN"] = 3] = "TAINTED_MULLIGAN";
})(HiveVariant || (HiveVariant = {}));
/** For `EntityType.CHARGER` (23). */
export var ChargerVariant;
(function (ChargerVariant) {
    ChargerVariant[ChargerVariant["CHARGER"] = 0] = "CHARGER";
    ChargerVariant[ChargerVariant["DROWNED_CHARGER"] = 1] = "DROWNED_CHARGER";
    ChargerVariant[ChargerVariant["DANK_CHARGER"] = 2] = "DANK_CHARGER";
    ChargerVariant[ChargerVariant["CARRION_PRINCESS"] = 3] = "CARRION_PRINCESS";
})(ChargerVariant || (ChargerVariant = {}));
/** For `EntityType.GLOBIN` (24). */
export var GlobinVariant;
(function (GlobinVariant) {
    GlobinVariant[GlobinVariant["GLOBIN"] = 0] = "GLOBIN";
    GlobinVariant[GlobinVariant["GAZING_GLOBIN"] = 1] = "GAZING_GLOBIN";
    GlobinVariant[GlobinVariant["DANK_GLOBIN"] = 2] = "DANK_GLOBIN";
    GlobinVariant[GlobinVariant["CURSED_GLOBIN"] = 3] = "CURSED_GLOBIN";
})(GlobinVariant || (GlobinVariant = {}));
/** For `EntityType.BOOM_FLY` (25). */
export var BoomFlyVariant;
(function (BoomFlyVariant) {
    BoomFlyVariant[BoomFlyVariant["BOOM_FLY"] = 0] = "BOOM_FLY";
    BoomFlyVariant[BoomFlyVariant["RED_BOOM_FLY"] = 1] = "RED_BOOM_FLY";
    BoomFlyVariant[BoomFlyVariant["DROWNED_BOOM_FLY"] = 2] = "DROWNED_BOOM_FLY";
    BoomFlyVariant[BoomFlyVariant["DRAGON_FLY"] = 3] = "DRAGON_FLY";
    BoomFlyVariant[BoomFlyVariant["BONE_FLY"] = 4] = "BONE_FLY";
    BoomFlyVariant[BoomFlyVariant["SICK_BOOM_FLY"] = 5] = "SICK_BOOM_FLY";
    BoomFlyVariant[BoomFlyVariant["TAINTED_BOOM_FLY"] = 6] = "TAINTED_BOOM_FLY";
})(BoomFlyVariant || (BoomFlyVariant = {}));
/** For `EntityType.MAW` (26). */
export var MawVariant;
(function (MawVariant) {
    MawVariant[MawVariant["MAW"] = 0] = "MAW";
    MawVariant[MawVariant["RED_MAW"] = 1] = "RED_MAW";
    MawVariant[MawVariant["PSYCHIC_MAW"] = 2] = "PSYCHIC_MAW";
})(MawVariant || (MawVariant = {}));
/** For `EntityType.HOST` (27). */
export var HostVariant;
(function (HostVariant) {
    HostVariant[HostVariant["HOST"] = 0] = "HOST";
    HostVariant[HostVariant["RED_HOST"] = 1] = "RED_HOST";
    HostVariant[HostVariant["HARD_HOST"] = 2] = "HARD_HOST";
})(HostVariant || (HostVariant = {}));
/** For `EntityType.CHUB` (28). */
export var ChubVariant;
(function (ChubVariant) {
    ChubVariant[ChubVariant["CHUB"] = 0] = "CHUB";
    ChubVariant[ChubVariant["CHAD"] = 1] = "CHAD";
    ChubVariant[ChubVariant["CARRION_QUEEN"] = 2] = "CARRION_QUEEN";
})(ChubVariant || (ChubVariant = {}));
/** For `EntityType.HOPPER` (29). */
export var HopperVariant;
(function (HopperVariant) {
    HopperVariant[HopperVariant["HOPPER"] = 0] = "HOPPER";
    HopperVariant[HopperVariant["TRITE"] = 1] = "TRITE";
    HopperVariant[HopperVariant["EGGY"] = 2] = "EGGY";
    HopperVariant[HopperVariant["TAINTED_HOPPER"] = 3] = "TAINTED_HOPPER";
})(HopperVariant || (HopperVariant = {}));
/** For `EntityType.BOIL` (30). */
export var BoilVariant;
(function (BoilVariant) {
    BoilVariant[BoilVariant["BOIL"] = 0] = "BOIL";
    BoilVariant[BoilVariant["GUT"] = 1] = "GUT";
    BoilVariant[BoilVariant["SACK"] = 2] = "SACK";
})(BoilVariant || (BoilVariant = {}));
/** For `EntityType.SPITTY` (31). */
export var SpittyVariant;
(function (SpittyVariant) {
    SpittyVariant[SpittyVariant["SPITTY"] = 0] = "SPITTY";
    SpittyVariant[SpittyVariant["TAINTED_SPITTY"] = 1] = "TAINTED_SPITTY";
})(SpittyVariant || (SpittyVariant = {}));
/**
 * For `EntityType.FIREPLACE` (33).
 *
 * Also see the `FireplaceGridEntityVariant` enum, which is different and used for the grid entity
 * version.
 */
export var FireplaceVariant;
(function (FireplaceVariant) {
    FireplaceVariant[FireplaceVariant["NORMAL"] = 0] = "NORMAL";
    FireplaceVariant[FireplaceVariant["RED"] = 1] = "RED";
    FireplaceVariant[FireplaceVariant["BLUE"] = 2] = "BLUE";
    FireplaceVariant[FireplaceVariant["PURPLE"] = 3] = "PURPLE";
    FireplaceVariant[FireplaceVariant["WHITE"] = 4] = "WHITE";
    FireplaceVariant[FireplaceVariant["MOVEABLE"] = 10] = "MOVEABLE";
    FireplaceVariant[FireplaceVariant["COAL"] = 11] = "COAL";
    FireplaceVariant[FireplaceVariant["MOVEABLE_BLUE"] = 12] = "MOVEABLE_BLUE";
    FireplaceVariant[FireplaceVariant["MOVEABLE_PURPLE"] = 13] = "MOVEABLE_PURPLE";
})(FireplaceVariant || (FireplaceVariant = {}));
/** For `EntityType.LEAPER` (34). */
export var LeaperVariant;
(function (LeaperVariant) {
    LeaperVariant[LeaperVariant["LEAPER"] = 0] = "LEAPER";
    LeaperVariant[LeaperVariant["STICKY_LEAPER"] = 1] = "STICKY_LEAPER";
})(LeaperVariant || (LeaperVariant = {}));
/** For `EntityType.MR_MAW` (35). */
export var MrMawVariant;
(function (MrMawVariant) {
    MrMawVariant[MrMawVariant["MR_MAW"] = 0] = "MR_MAW";
    MrMawVariant[MrMawVariant["MR_MAW_HEAD"] = 1] = "MR_MAW_HEAD";
    MrMawVariant[MrMawVariant["MR_RED_MAW"] = 2] = "MR_RED_MAW";
    MrMawVariant[MrMawVariant["MR_RED_MAW_HEAD"] = 3] = "MR_RED_MAW_HEAD";
    MrMawVariant[MrMawVariant["MR_MAW_NECK"] = 10] = "MR_MAW_NECK";
})(MrMawVariant || (MrMawVariant = {}));
/** For `EntityType.BABY` (38). */
export var BabyVariant;
(function (BabyVariant) {
    BabyVariant[BabyVariant["BABY"] = 0] = "BABY";
    BabyVariant[BabyVariant["ANGELIC_BABY"] = 1] = "ANGELIC_BABY";
    BabyVariant[BabyVariant["ULTRA_PRIDE_BABY"] = 2] = "ULTRA_PRIDE_BABY";
    BabyVariant[BabyVariant["WRINKLY_BABY"] = 3] = "WRINKLY_BABY";
})(BabyVariant || (BabyVariant = {}));
/** For `EntityType.VIS` (39). */
export var VisVariant;
(function (VisVariant) {
    VisVariant[VisVariant["VIS"] = 0] = "VIS";
    VisVariant[VisVariant["DOUBLE_VIS"] = 1] = "DOUBLE_VIS";
    VisVariant[VisVariant["CHUBBER"] = 2] = "CHUBBER";
    VisVariant[VisVariant["SCARRED_DOUBLE_VIS"] = 3] = "SCARRED_DOUBLE_VIS";
    VisVariant[VisVariant["CHUBBER_PROJECTILE"] = 22] = "CHUBBER_PROJECTILE";
})(VisVariant || (VisVariant = {}));
/** For `EntityType.GUTS` (40). */
export var GutsVariant;
(function (GutsVariant) {
    GutsVariant[GutsVariant["GUTS"] = 0] = "GUTS";
    GutsVariant[GutsVariant["SCARRED_GUTS"] = 1] = "SCARRED_GUTS";
    GutsVariant[GutsVariant["SLOG"] = 2] = "SLOG";
})(GutsVariant || (GutsVariant = {}));
/** For `EntityType.KNIGHT` (41). */
export var KnightVariant;
(function (KnightVariant) {
    KnightVariant[KnightVariant["KNIGHT"] = 0] = "KNIGHT";
    KnightVariant[KnightVariant["SELFLESS_KNIGHT"] = 1] = "SELFLESS_KNIGHT";
    KnightVariant[KnightVariant["LOOSE_KNIGHT"] = 2] = "LOOSE_KNIGHT";
    KnightVariant[KnightVariant["BRAINLESS_KNIGHT"] = 3] = "BRAINLESS_KNIGHT";
    KnightVariant[KnightVariant["BLACK_KNIGHT"] = 4] = "BLACK_KNIGHT";
})(KnightVariant || (KnightVariant = {}));
/** For `EntityType.GRIMACE` (42). */
export var GrimaceVariant;
(function (GrimaceVariant) {
    GrimaceVariant[GrimaceVariant["STONE_GRIMACE"] = 0] = "STONE_GRIMACE";
    GrimaceVariant[GrimaceVariant["VOMIT_GRIMACE"] = 1] = "VOMIT_GRIMACE";
    GrimaceVariant[GrimaceVariant["TRIPLE_GRIMACE"] = 2] = "TRIPLE_GRIMACE";
})(GrimaceVariant || (GrimaceVariant = {}));
/** For `EntityType.MONSTRO_2` (43). */
export var Monstro2Variant;
(function (Monstro2Variant) {
    Monstro2Variant[Monstro2Variant["MONSTRO_2"] = 0] = "MONSTRO_2";
    Monstro2Variant[Monstro2Variant["GISH"] = 1] = "GISH";
})(Monstro2Variant || (Monstro2Variant = {}));
/** For `EntityType.POKY` (44). */
export var PokyVariant;
(function (PokyVariant) {
    PokyVariant[PokyVariant["POKY"] = 0] = "POKY";
    PokyVariant[PokyVariant["SLIDE"] = 1] = "SLIDE";
})(PokyVariant || (PokyVariant = {}));
/** For `EntityType.MOM` (45). */
export var MomVariant;
(function (MomVariant) {
    MomVariant[MomVariant["MOM"] = 0] = "MOM";
    MomVariant[MomVariant["STOMP"] = 10] = "STOMP";
})(MomVariant || (MomVariant = {}));
/** For `EntityType.SLOTH` (46). */
export var SlothVariant;
(function (SlothVariant) {
    SlothVariant[SlothVariant["SLOTH"] = 0] = "SLOTH";
    SlothVariant[SlothVariant["SUPER_SLOTH"] = 1] = "SUPER_SLOTH";
    SlothVariant[SlothVariant["ULTRA_PRIDE"] = 2] = "ULTRA_PRIDE";
})(SlothVariant || (SlothVariant = {}));
/** For `EntityType.LUST` (47). */
export var LustVariant;
(function (LustVariant) {
    LustVariant[LustVariant["LUST"] = 0] = "LUST";
    LustVariant[LustVariant["SUPER_LUST"] = 1] = "SUPER_LUST";
})(LustVariant || (LustVariant = {}));
/** For `EntityType.WRATH` (48). */
export var WrathVariant;
(function (WrathVariant) {
    WrathVariant[WrathVariant["WRATH"] = 0] = "WRATH";
    WrathVariant[WrathVariant["SUPER_WRATH"] = 1] = "SUPER_WRATH";
})(WrathVariant || (WrathVariant = {}));
/** For `EntityType.GLUTTONY` (49). */
export var GluttonyVariant;
(function (GluttonyVariant) {
    GluttonyVariant[GluttonyVariant["GLUTTONY"] = 0] = "GLUTTONY";
    GluttonyVariant[GluttonyVariant["SUPER_GLUTTONY"] = 1] = "SUPER_GLUTTONY";
})(GluttonyVariant || (GluttonyVariant = {}));
/** For `EntityType.GREED` (50). */
export var GreedVariant;
(function (GreedVariant) {
    GreedVariant[GreedVariant["GREED"] = 0] = "GREED";
    GreedVariant[GreedVariant["SUPER_GREED"] = 1] = "SUPER_GREED";
})(GreedVariant || (GreedVariant = {}));
/** For `EntityType.ENVY` (51). */
export var EnvyVariant;
(function (EnvyVariant) {
    EnvyVariant[EnvyVariant["ENVY"] = 0] = "ENVY";
    EnvyVariant[EnvyVariant["SUPER_ENVY"] = 1] = "SUPER_ENVY";
    EnvyVariant[EnvyVariant["ENVY_BIG"] = 10] = "ENVY_BIG";
    EnvyVariant[EnvyVariant["SUPER_ENVY_BIG"] = 11] = "SUPER_ENVY_BIG";
    EnvyVariant[EnvyVariant["ENVY_MEDIUM"] = 20] = "ENVY_MEDIUM";
    EnvyVariant[EnvyVariant["SUPER_ENVY_MEDIUM"] = 21] = "SUPER_ENVY_MEDIUM";
    EnvyVariant[EnvyVariant["ENVY_SMALL"] = 30] = "ENVY_SMALL";
    EnvyVariant[EnvyVariant["SUPER_ENVY_SMALL"] = 31] = "SUPER_ENVY_SMALL";
})(EnvyVariant || (EnvyVariant = {}));
/** For `EntityType.PRIDE` (52). */
export var PrideVariant;
(function (PrideVariant) {
    PrideVariant[PrideVariant["PRIDE"] = 0] = "PRIDE";
    PrideVariant[PrideVariant["SUPER_PRIDE"] = 1] = "SUPER_PRIDE";
    // Ultra Pride is part of the `SlothVariant` enum.
})(PrideVariant || (PrideVariant = {}));
/** For `EntityType.DOPLE` (53). */
export var DopleVariant;
(function (DopleVariant) {
    DopleVariant[DopleVariant["DOPLE"] = 0] = "DOPLE";
    DopleVariant[DopleVariant["EVIL_TWIN"] = 1] = "EVIL_TWIN";
})(DopleVariant || (DopleVariant = {}));
/** For `EntityType.LEECH` (55). */
export var LeechVariant;
(function (LeechVariant) {
    LeechVariant[LeechVariant["LEECH"] = 0] = "LEECH";
    LeechVariant[LeechVariant["KAMIKAZE_LEECH"] = 1] = "KAMIKAZE_LEECH";
    LeechVariant[LeechVariant["HOLY_LEECH"] = 2] = "HOLY_LEECH";
})(LeechVariant || (LeechVariant = {}));
/** For `EntityType.MEMBRAIN` (57). */
export var MemBrainVariant;
(function (MemBrainVariant) {
    MemBrainVariant[MemBrainVariant["MEMBRAIN"] = 0] = "MEMBRAIN";
    MemBrainVariant[MemBrainVariant["MAMA_GUTS"] = 1] = "MAMA_GUTS";
    MemBrainVariant[MemBrainVariant["DEAD_MEAT"] = 2] = "DEAD_MEAT";
})(MemBrainVariant || (MemBrainVariant = {}));
/** For `EntityType.PARA_BITE` (58). */
export var ParaBiteVariant;
(function (ParaBiteVariant) {
    ParaBiteVariant[ParaBiteVariant["PARA_BITE"] = 0] = "PARA_BITE";
    ParaBiteVariant[ParaBiteVariant["SCARRED_PARA_BITE"] = 1] = "SCARRED_PARA_BITE";
})(ParaBiteVariant || (ParaBiteVariant = {}));
/** For `EntityType.EYE` (60). */
export var EyeVariant;
(function (EyeVariant) {
    EyeVariant[EyeVariant["EYE"] = 0] = "EYE";
    EyeVariant[EyeVariant["BLOODSHOT_EYE"] = 1] = "BLOODSHOT_EYE";
    EyeVariant[EyeVariant["HOLY_EYE"] = 2] = "HOLY_EYE";
})(EyeVariant || (EyeVariant = {}));
/** For `EntityType.SUCKER` (61). */
export var SuckerVariant;
(function (SuckerVariant) {
    SuckerVariant[SuckerVariant["SUCKER"] = 0] = "SUCKER";
    SuckerVariant[SuckerVariant["SPIT"] = 1] = "SPIT";
    SuckerVariant[SuckerVariant["SOUL_SUCKER"] = 2] = "SOUL_SUCKER";
    SuckerVariant[SuckerVariant["INK"] = 3] = "INK";
    SuckerVariant[SuckerVariant["MAMA_FLY"] = 4] = "MAMA_FLY";
    SuckerVariant[SuckerVariant["BULB"] = 5] = "BULB";
    SuckerVariant[SuckerVariant["BLOOD_FLY"] = 6] = "BLOOD_FLY";
    SuckerVariant[SuckerVariant["TAINTED_SUCKER"] = 7] = "TAINTED_SUCKER";
})(SuckerVariant || (SuckerVariant = {}));
/** For `EntityType.PIN` (62). */
export var PinVariant;
(function (PinVariant) {
    PinVariant[PinVariant["PIN"] = 0] = "PIN";
    PinVariant[PinVariant["SCOLEX"] = 1] = "SCOLEX";
    PinVariant[PinVariant["FRAIL"] = 2] = "FRAIL";
    PinVariant[PinVariant["WORMWOOD"] = 3] = "WORMWOOD";
})(PinVariant || (PinVariant = {}));
/** For `EntityType.WAR` (65). */
export var WarVariant;
(function (WarVariant) {
    WarVariant[WarVariant["WAR"] = 0] = "WAR";
    WarVariant[WarVariant["CONQUEST"] = 1] = "CONQUEST";
    WarVariant[WarVariant["WAR_WITHOUT_HORSE"] = 2] = "WAR_WITHOUT_HORSE";
})(WarVariant || (WarVariant = {}));
/** For `EntityType.DEATH` (66). */
export var DeathVariant;
(function (DeathVariant) {
    DeathVariant[DeathVariant["DEATH"] = 0] = "DEATH";
    DeathVariant[DeathVariant["DEATH_SCYTHE"] = 10] = "DEATH_SCYTHE";
    DeathVariant[DeathVariant["DEATH_HORSE"] = 20] = "DEATH_HORSE";
    DeathVariant[DeathVariant["DEATH_WITHOUT_HORSE"] = 30] = "DEATH_WITHOUT_HORSE";
})(DeathVariant || (DeathVariant = {}));
/** For `EntityType.DUKE_OF_FLIES` (67). */
export var DukeOfFliesVariant;
(function (DukeOfFliesVariant) {
    DukeOfFliesVariant[DukeOfFliesVariant["DUKE_OF_FLIES"] = 0] = "DUKE_OF_FLIES";
    DukeOfFliesVariant[DukeOfFliesVariant["HUSK"] = 1] = "HUSK";
})(DukeOfFliesVariant || (DukeOfFliesVariant = {}));
/** For `EntityType.PEEP` (68). */
export var PeepVariant;
(function (PeepVariant) {
    PeepVariant[PeepVariant["PEEP"] = 0] = "PEEP";
    PeepVariant[PeepVariant["BLOAT"] = 1] = "BLOAT";
    PeepVariant[PeepVariant["PEEP_EYE"] = 10] = "PEEP_EYE";
    PeepVariant[PeepVariant["BLOAT_EYE"] = 11] = "BLOAT_EYE";
})(PeepVariant || (PeepVariant = {}));
/** For `EntityType.LOKI` (69). */
export var LokiVariant;
(function (LokiVariant) {
    LokiVariant[LokiVariant["LOKI"] = 0] = "LOKI";
    LokiVariant[LokiVariant["LOKII"] = 1] = "LOKII";
})(LokiVariant || (LokiVariant = {}));
/**
 * For:
 * - `EntityType.FISTULA_BIG` (71)
 * - `EntityType.FISTULA_MEDIUM` (72)
 * - `EntityType.FISTULA_SMALL` (73)
 */
export var FistulaVariant;
(function (FistulaVariant) {
    FistulaVariant[FistulaVariant["FISTULA"] = 0] = "FISTULA";
    FistulaVariant[FistulaVariant["TERATOMA"] = 1] = "TERATOMA";
})(FistulaVariant || (FistulaVariant = {}));
/** For `EntityType.MOMS_HEART` (78). */
export var MomsHeartVariant;
(function (MomsHeartVariant) {
    MomsHeartVariant[MomsHeartVariant["MOMS_HEART"] = 0] = "MOMS_HEART";
    MomsHeartVariant[MomsHeartVariant["IT_LIVES"] = 1] = "IT_LIVES";
    MomsHeartVariant[MomsHeartVariant["MOMS_GUTS"] = 2] = "MOMS_GUTS";
})(MomsHeartVariant || (MomsHeartVariant = {}));
/** For `EntityType.GEMINI` (79). */
export var GeminiVariant;
(function (GeminiVariant) {
    GeminiVariant[GeminiVariant["GEMINI"] = 0] = "GEMINI";
    GeminiVariant[GeminiVariant["STEVEN"] = 1] = "STEVEN";
    GeminiVariant[GeminiVariant["BLIGHTED_OVUM"] = 2] = "BLIGHTED_OVUM";
    GeminiVariant[GeminiVariant["GEMINI_BABY"] = 10] = "GEMINI_BABY";
    GeminiVariant[GeminiVariant["STEVEN_BABY"] = 11] = "STEVEN_BABY";
    GeminiVariant[GeminiVariant["BLIGHTED_OVUM_BABY"] = 12] = "BLIGHTED_OVUM_BABY";
    GeminiVariant[GeminiVariant["UMBILICAL_CORD"] = 20] = "UMBILICAL_CORD";
})(GeminiVariant || (GeminiVariant = {}));
/** For `EntityType.FALLEN` (81). */
export var FallenVariant;
(function (FallenVariant) {
    FallenVariant[FallenVariant["FALLEN"] = 0] = "FALLEN";
    FallenVariant[FallenVariant["KRAMPUS"] = 1] = "KRAMPUS";
})(FallenVariant || (FallenVariant = {}));
/** For `EntityType.SATAN` (84). */
export var SatanVariant;
(function (SatanVariant) {
    SatanVariant[SatanVariant["SATAN"] = 0] = "SATAN";
    SatanVariant[SatanVariant["STOMP"] = 10] = "STOMP";
})(SatanVariant || (SatanVariant = {}));
/** For `EntityType.GURGLE` (87). */
export var GurgleVariant;
(function (GurgleVariant) {
    GurgleVariant[GurgleVariant["GURGLE"] = 0] = "GURGLE";
    GurgleVariant[GurgleVariant["CRACKLE"] = 1] = "CRACKLE";
})(GurgleVariant || (GurgleVariant = {}));
/** For `EntityType.WALKING_BOIL` (88). */
export var WalkingBoilVariant;
(function (WalkingBoilVariant) {
    WalkingBoilVariant[WalkingBoilVariant["WALKING_BOIL"] = 0] = "WALKING_BOIL";
    WalkingBoilVariant[WalkingBoilVariant["WALKING_GUT"] = 1] = "WALKING_GUT";
    WalkingBoilVariant[WalkingBoilVariant["WALKING_SACK"] = 2] = "WALKING_SACK";
})(WalkingBoilVariant || (WalkingBoilVariant = {}));
/** For `EntityType.HEART` (92). */
export var HeartVariant;
(function (HeartVariant) {
    HeartVariant[HeartVariant["HEART"] = 0] = "HEART";
    HeartVariant[HeartVariant["HALF_HEART"] = 1] = "HALF_HEART";
})(HeartVariant || (HeartVariant = {}));
/** For `EntityType.MASK` (93). */
export var MaskVariant;
(function (MaskVariant) {
    MaskVariant[MaskVariant["MASK"] = 0] = "MASK";
    MaskVariant[MaskVariant["MASK_2"] = 1] = "MASK_2";
})(MaskVariant || (MaskVariant = {}));
/** For `EntityType.WIDOW` (100). */
export var WidowVariant;
(function (WidowVariant) {
    WidowVariant[WidowVariant["WIDOW"] = 0] = "WIDOW";
    WidowVariant[WidowVariant["WRETCHED"] = 1] = "WRETCHED";
})(WidowVariant || (WidowVariant = {}));
/** For `EntityType.DADDY_LONG_LEGS` (101). */
export var DaddyLongLegsVariant;
(function (DaddyLongLegsVariant) {
    DaddyLongLegsVariant[DaddyLongLegsVariant["DADDY_LONG_LEGS"] = 0] = "DADDY_LONG_LEGS";
    DaddyLongLegsVariant[DaddyLongLegsVariant["TRIACHNID"] = 1] = "TRIACHNID";
})(DaddyLongLegsVariant || (DaddyLongLegsVariant = {}));
/** For `EntityType.ISAAC` (102). */
export var IsaacVariant;
(function (IsaacVariant) {
    IsaacVariant[IsaacVariant["ISAAC"] = 0] = "ISAAC";
    IsaacVariant[IsaacVariant["BLUE_BABY"] = 1] = "BLUE_BABY";
    IsaacVariant[IsaacVariant["BLUE_BABY_HUSH"] = 2] = "BLUE_BABY_HUSH";
})(IsaacVariant || (IsaacVariant = {}));
/** For `EntityType.CONSTANT_STONE_SHOOTER` (202). */
export var ConstantStoneShooterVariant;
(function (ConstantStoneShooterVariant) {
    ConstantStoneShooterVariant[ConstantStoneShooterVariant["CONSTANT_STONE_SHOOTER"] = 0] = "CONSTANT_STONE_SHOOTER";
    ConstantStoneShooterVariant[ConstantStoneShooterVariant["CROSS_STONE_SHOOTER"] = 10] = "CROSS_STONE_SHOOTER";
    ConstantStoneShooterVariant[ConstantStoneShooterVariant["CROSS_STONE_SHOOTER_ALWAYS_ON"] = 11] = "CROSS_STONE_SHOOTER_ALWAYS_ON";
})(ConstantStoneShooterVariant || (ConstantStoneShooterVariant = {}));
/** For `EntityType.BABY_LONG_LEGS` (206). */
export var BabyLongLegsVariant;
(function (BabyLongLegsVariant) {
    BabyLongLegsVariant[BabyLongLegsVariant["BABY_LONG_LEGS"] = 0] = "BABY_LONG_LEGS";
    BabyLongLegsVariant[BabyLongLegsVariant["SMALL_BABY_LONG_LEGS"] = 1] = "SMALL_BABY_LONG_LEGS";
})(BabyLongLegsVariant || (BabyLongLegsVariant = {}));
/** For `EntityType.CRAZY_LONG_LEGS` (207). */
export var CrazyLongLegsVariant;
(function (CrazyLongLegsVariant) {
    CrazyLongLegsVariant[CrazyLongLegsVariant["CRAZY_LONG_LEGS"] = 0] = "CRAZY_LONG_LEGS";
    CrazyLongLegsVariant[CrazyLongLegsVariant["SMALL_CRAZY_LONG_LEGS"] = 1] = "SMALL_CRAZY_LONG_LEGS";
})(CrazyLongLegsVariant || (CrazyLongLegsVariant = {}));
/** For `EntityType.FATTY` (208). */
export var FattyVariant;
(function (FattyVariant) {
    FattyVariant[FattyVariant["FATTY"] = 0] = "FATTY";
    FattyVariant[FattyVariant["PALE_FATTY"] = 1] = "PALE_FATTY";
    FattyVariant[FattyVariant["FLAMING_FATTY"] = 2] = "FLAMING_FATTY";
})(FattyVariant || (FattyVariant = {}));
/** For `EntityType.DEATHS_HEAD` (212). */
export var DeathsHeadVariant;
(function (DeathsHeadVariant) {
    DeathsHeadVariant[DeathsHeadVariant["DEATHS_HEAD"] = 0] = "DEATHS_HEAD";
    /**
     * This is the only Death's Head variant that does not rely on other enemies in the room being
     * alive.
     */
    DeathsHeadVariant[DeathsHeadVariant["DANK_DEATHS_HEAD"] = 1] = "DANK_DEATHS_HEAD";
    DeathsHeadVariant[DeathsHeadVariant["CURSED_DEATHS_HEAD"] = 2] = "CURSED_DEATHS_HEAD";
    DeathsHeadVariant[DeathsHeadVariant["BRIMSTONE_DEATHS_HEAD"] = 3] = "BRIMSTONE_DEATHS_HEAD";
    DeathsHeadVariant[DeathsHeadVariant["RED_SKULL"] = 4] = "RED_SKULL";
})(DeathsHeadVariant || (DeathsHeadVariant = {}));
/** For `EntityType.SWINGER` (216). */
export var SwingerVariant;
(function (SwingerVariant) {
    SwingerVariant[SwingerVariant["SWINGER"] = 0] = "SWINGER";
    SwingerVariant[SwingerVariant["SWINGER_HEAD"] = 1] = "SWINGER_HEAD";
    SwingerVariant[SwingerVariant["SWINGER_NECK"] = 10] = "SWINGER_NECK";
})(SwingerVariant || (SwingerVariant = {}));
/** For `EntityType.DIP` (217). */
export var DipVariant;
(function (DipVariant) {
    DipVariant[DipVariant["DIP"] = 0] = "DIP";
    DipVariant[DipVariant["CORN"] = 1] = "CORN";
    DipVariant[DipVariant["BROWNIE_CORN"] = 2] = "BROWNIE_CORN";
    DipVariant[DipVariant["BIG_CORN"] = 3] = "BIG_CORN";
})(DipVariant || (DipVariant = {}));
/** For `EntityType.SQUIRT` (220). */
export var SquirtVariant;
(function (SquirtVariant) {
    SquirtVariant[SquirtVariant["SQUIRT"] = 0] = "SQUIRT";
    SquirtVariant[SquirtVariant["DANK_SQUIRT"] = 1] = "DANK_SQUIRT";
})(SquirtVariant || (SquirtVariant = {}));
/** For `EntityType.SKINNY` (226). */
export var SkinnyVariant;
(function (SkinnyVariant) {
    SkinnyVariant[SkinnyVariant["SKINNY"] = 0] = "SKINNY";
    SkinnyVariant[SkinnyVariant["ROTTY"] = 1] = "ROTTY";
    SkinnyVariant[SkinnyVariant["CRISPY"] = 2] = "CRISPY";
})(SkinnyVariant || (SkinnyVariant = {}));
/** For `EntityType.BONY` (227). */
export var BonyVariant;
(function (BonyVariant) {
    BonyVariant[BonyVariant["BONY"] = 0] = "BONY";
    BonyVariant[BonyVariant["HOLY_BONY"] = 1] = "HOLY_BONY";
})(BonyVariant || (BonyVariant = {}));
/** For `EntityType.HOMUNCULUS` (228). */
export var HomunculusVariant;
(function (HomunculusVariant) {
    HomunculusVariant[HomunculusVariant["HOMUNCULUS"] = 0] = "HOMUNCULUS";
    HomunculusVariant[HomunculusVariant["HOMUNCULUS_CORD"] = 10] = "HOMUNCULUS_CORD";
})(HomunculusVariant || (HomunculusVariant = {}));
/** For `EntityType.TUMOR` (229). */
export var TumorVariant;
(function (TumorVariant) {
    TumorVariant[TumorVariant["TUMOR"] = 0] = "TUMOR";
    TumorVariant[TumorVariant["PLANETOID"] = 1] = "PLANETOID";
})(TumorVariant || (TumorVariant = {}));
/** For `EntityType.NERVE_ENDING` (231). */
export var NerveEndingVariant;
(function (NerveEndingVariant) {
    NerveEndingVariant[NerveEndingVariant["NERVE_ENDING"] = 0] = "NERVE_ENDING";
    NerveEndingVariant[NerveEndingVariant["NERVE_ENDING_2"] = 1] = "NERVE_ENDING_2";
})(NerveEndingVariant || (NerveEndingVariant = {}));
/** For `EntityType.GURGLING` (237). */
export var GurglingVariant;
(function (GurglingVariant) {
    GurglingVariant[GurglingVariant["GURGLING"] = 0] = "GURGLING";
    GurglingVariant[GurglingVariant["GURGLING_BOSS"] = 1] = "GURGLING_BOSS";
    GurglingVariant[GurglingVariant["TURDLING"] = 2] = "TURDLING";
})(GurglingVariant || (GurglingVariant = {}));
/** For `EntityType.GRUB` (239). */
export var GrubVariant;
(function (GrubVariant) {
    GrubVariant[GrubVariant["GRUB"] = 0] = "GRUB";
    GrubVariant[GrubVariant["CORPSE_EATER"] = 1] = "CORPSE_EATER";
    GrubVariant[GrubVariant["CARRION_RIDER"] = 2] = "CARRION_RIDER";
})(GrubVariant || (GrubVariant = {}));
/** For `EntityType.WALL_CREEP` (240). */
export var WallCreepVariant;
(function (WallCreepVariant) {
    WallCreepVariant[WallCreepVariant["WALL_CREEP"] = 0] = "WALL_CREEP";
    WallCreepVariant[WallCreepVariant["SOY_CREEP"] = 1] = "SOY_CREEP";
    WallCreepVariant[WallCreepVariant["RAG_CREEP"] = 2] = "RAG_CREEP";
    WallCreepVariant[WallCreepVariant["TAINTED_SOY_CREEP"] = 3] = "TAINTED_SOY_CREEP";
})(WallCreepVariant || (WallCreepVariant = {}));
/** For `EntityType.RAGE_CREEP` (241). */
export var RageCreepVariant;
(function (RageCreepVariant) {
    RageCreepVariant[RageCreepVariant["RAGE_CREEP"] = 0] = "RAGE_CREEP";
    RageCreepVariant[RageCreepVariant["SPLIT_RAGE_CREEP"] = 1] = "SPLIT_RAGE_CREEP";
})(RageCreepVariant || (RageCreepVariant = {}));
/** For `EntityType.ROUND_WORM` (244). */
export var RoundWormVariant;
(function (RoundWormVariant) {
    RoundWormVariant[RoundWormVariant["ROUND_WORM"] = 0] = "ROUND_WORM";
    RoundWormVariant[RoundWormVariant["TUBE_WORM"] = 1] = "TUBE_WORM";
    RoundWormVariant[RoundWormVariant["TAINTED_ROUND_WORM"] = 2] = "TAINTED_ROUND_WORM";
    RoundWormVariant[RoundWormVariant["TAINTED_TUBE_WORM"] = 3] = "TAINTED_TUBE_WORM";
})(RoundWormVariant || (RoundWormVariant = {}));
/** For `EntityType.POOP` (245). */
export var PoopEntityVariant;
(function (PoopEntityVariant) {
    PoopEntityVariant[PoopEntityVariant["NORMAL"] = 0] = "NORMAL";
    PoopEntityVariant[PoopEntityVariant["GOLDEN"] = 1] = "GOLDEN";
    PoopEntityVariant[PoopEntityVariant["STONE"] = 11] = "STONE";
    PoopEntityVariant[PoopEntityVariant["CORNY"] = 12] = "CORNY";
    PoopEntityVariant[PoopEntityVariant["BURNING"] = 13] = "BURNING";
    PoopEntityVariant[PoopEntityVariant["STINKY"] = 14] = "STINKY";
    PoopEntityVariant[PoopEntityVariant["BLACK"] = 15] = "BLACK";
    PoopEntityVariant[PoopEntityVariant["WHITE"] = 16] = "WHITE";
})(PoopEntityVariant || (PoopEntityVariant = {}));
/** For `EntityType.RAGLING` (246). */
export var RaglingVariant;
(function (RaglingVariant) {
    RaglingVariant[RaglingVariant["RAGLING"] = 0] = "RAGLING";
    RaglingVariant[RaglingVariant["RAG_MANS_RAGLING"] = 1] = "RAG_MANS_RAGLING";
})(RaglingVariant || (RaglingVariant = {}));
/** For `EntityType.BEGOTTEN` (251). */
export var BegottenVariant;
(function (BegottenVariant) {
    BegottenVariant[BegottenVariant["BEGOTTEN"] = 0] = "BEGOTTEN";
    BegottenVariant[BegottenVariant["BEGOTTEN_CHAIN"] = 10] = "BEGOTTEN_CHAIN";
})(BegottenVariant || (BegottenVariant = {}));
/** For `EntityType.CONJOINED_FATTY` (257). */
export var ConjoinedFattyVariant;
(function (ConjoinedFattyVariant) {
    ConjoinedFattyVariant[ConjoinedFattyVariant["CONJOINED_FATTY"] = 0] = "CONJOINED_FATTY";
    ConjoinedFattyVariant[ConjoinedFattyVariant["BLUE_CONJOINED_FATTY"] = 1] = "BLUE_CONJOINED_FATTY";
})(ConjoinedFattyVariant || (ConjoinedFattyVariant = {}));
/** For `EntityType.HAUNT` (260). */
export var HauntVariant;
(function (HauntVariant) {
    HauntVariant[HauntVariant["HAUNT"] = 0] = "HAUNT";
    HauntVariant[HauntVariant["LIL_HAUNT"] = 10] = "LIL_HAUNT";
})(HauntVariant || (HauntVariant = {}));
/** For `EntityType.DINGLE` (261). */
export var DingleVariant;
(function (DingleVariant) {
    DingleVariant[DingleVariant["DINGLE"] = 0] = "DINGLE";
    DingleVariant[DingleVariant["DANGLE"] = 1] = "DANGLE";
})(DingleVariant || (DingleVariant = {}));
/** For `EntityType.MAMA_GURDY` (266). */
export var MamaGurdyVariant;
(function (MamaGurdyVariant) {
    MamaGurdyVariant[MamaGurdyVariant["MAMA_GURDY"] = 0] = "MAMA_GURDY";
    MamaGurdyVariant[MamaGurdyVariant["LEFT_HAND"] = 1] = "LEFT_HAND";
    MamaGurdyVariant[MamaGurdyVariant["RIGHT_HAND"] = 2] = "RIGHT_HAND";
})(MamaGurdyVariant || (MamaGurdyVariant = {}));
/** For `EntityType.POLYCEPHALUS` (269). */
export var PolycephalusVariant;
(function (PolycephalusVariant) {
    PolycephalusVariant[PolycephalusVariant["POLYCEPHALUS"] = 0] = "POLYCEPHALUS";
    PolycephalusVariant[PolycephalusVariant["PILE"] = 1] = "PILE";
})(PolycephalusVariant || (PolycephalusVariant = {}));
/** For `EntityType.URIEL` (271) and `EntityType.GABRIEL` (272). */
export var AngelVariant;
(function (AngelVariant) {
    AngelVariant[AngelVariant["NORMAL"] = 0] = "NORMAL";
    AngelVariant[AngelVariant["FALLEN"] = 1] = "FALLEN";
})(AngelVariant || (AngelVariant = {}));
/** For `EntityType.LAMB` (273). */
export var LambVariant;
(function (LambVariant) {
    LambVariant[LambVariant["LAMB"] = 0] = "LAMB";
    LambVariant[LambVariant["BODY"] = 10] = "BODY";
})(LambVariant || (LambVariant = {}));
/** For `EntityType.MEGA_SATAN` (274) and `EntityType.MEGA_SATAN_2` (275). */
export var MegaSatanVariant;
(function (MegaSatanVariant) {
    MegaSatanVariant[MegaSatanVariant["MEGA_SATAN"] = 0] = "MEGA_SATAN";
    MegaSatanVariant[MegaSatanVariant["MEGA_SATAN_RIGHT_HAND"] = 1] = "MEGA_SATAN_RIGHT_HAND";
    MegaSatanVariant[MegaSatanVariant["MEGA_SATAN_LEFT_HAND"] = 2] = "MEGA_SATAN_LEFT_HAND";
})(MegaSatanVariant || (MegaSatanVariant = {}));
/** For `EntityType.PITFALL` (291). */
export var PitfallVariant;
(function (PitfallVariant) {
    PitfallVariant[PitfallVariant["PITFALL"] = 0] = "PITFALL";
    PitfallVariant[PitfallVariant["SUCTION_PITFALL"] = 1] = "SUCTION_PITFALL";
    PitfallVariant[PitfallVariant["TELEPORT_PITFALL"] = 2] = "TELEPORT_PITFALL";
})(PitfallVariant || (PitfallVariant = {}));
/** For `EntityType.MOVABLE_TNT` (292). */
export var MoveableTNTVariant;
(function (MoveableTNTVariant) {
    MoveableTNTVariant[MoveableTNTVariant["MOVEABLE_TNT"] = 0] = "MOVEABLE_TNT";
    MoveableTNTVariant[MoveableTNTVariant["MINE_CRAFTER"] = 1] = "MINE_CRAFTER";
})(MoveableTNTVariant || (MoveableTNTVariant = {}));
/** For `EntityType.ULTRA_COIN` (293). */
export var UltraCoinVariant;
(function (UltraCoinVariant) {
    UltraCoinVariant[UltraCoinVariant["SPINNER"] = 0] = "SPINNER";
    UltraCoinVariant[UltraCoinVariant["KEY"] = 1] = "KEY";
    UltraCoinVariant[UltraCoinVariant["BOMB"] = 2] = "BOMB";
    UltraCoinVariant[UltraCoinVariant["HEART"] = 3] = "HEART";
})(UltraCoinVariant || (UltraCoinVariant = {}));
/** For `EntityType.STONEY` (302). */
export var StoneyVariant;
(function (StoneyVariant) {
    StoneyVariant[StoneyVariant["STONEY"] = 0] = "STONEY";
    StoneyVariant[StoneyVariant["CROSS_STONEY"] = 10] = "CROSS_STONEY";
})(StoneyVariant || (StoneyVariant = {}));
/** For `EntityType.PORTAL` (306). */
export var PortalVariant;
(function (PortalVariant) {
    PortalVariant[PortalVariant["PORTAL"] = 0] = "PORTAL";
    PortalVariant[PortalVariant["LIL_PORTAL"] = 1] = "LIL_PORTAL";
})(PortalVariant || (PortalVariant = {}));
/** For `EntityType.LEPER` (310). */
export var LeperVariant;
(function (LeperVariant) {
    LeperVariant[LeperVariant["LEPER"] = 0] = "LEPER";
    LeperVariant[LeperVariant["LEPER_FLESH"] = 1] = "LEPER_FLESH";
})(LeperVariant || (LeperVariant = {}));
/** For `EntityType.MR_MINE` (311). */
export var MrMineVariant;
(function (MrMineVariant) {
    MrMineVariant[MrMineVariant["MR_MINE"] = 0] = "MR_MINE";
    MrMineVariant[MrMineVariant["MR_MINE_NECK"] = 10] = "MR_MINE_NECK";
})(MrMineVariant || (MrMineVariant = {}));
/** For `EntityType.LITTLE_HORN` (404). */
export var LittleHornVariant;
(function (LittleHornVariant) {
    LittleHornVariant[LittleHornVariant["LITTLE_HORN"] = 0] = "LITTLE_HORN";
    LittleHornVariant[LittleHornVariant["DARK_BALL"] = 1] = "DARK_BALL";
})(LittleHornVariant || (LittleHornVariant = {}));
/** For `EntityType.RAG_MAN` (405). */
export var RagManVariant;
(function (RagManVariant) {
    RagManVariant[RagManVariant["RAG_MAN"] = 0] = "RAG_MAN";
    RagManVariant[RagManVariant["RAG_MAN_HEAD"] = 1] = "RAG_MAN_HEAD";
})(RagManVariant || (RagManVariant = {}));
/** For `EntityType.ULTRA_GREED` (406). */
export var UltraGreedVariant;
(function (UltraGreedVariant) {
    UltraGreedVariant[UltraGreedVariant["ULTRA_GREED"] = 0] = "ULTRA_GREED";
    UltraGreedVariant[UltraGreedVariant["ULTRA_GREEDIER"] = 1] = "ULTRA_GREEDIER";
})(UltraGreedVariant || (UltraGreedVariant = {}));
/** For `EntityType.RAG_MEGA` (409). */
export var RagMegaVariant;
(function (RagMegaVariant) {
    RagMegaVariant[RagMegaVariant["RAG_MEGA"] = 0] = "RAG_MEGA";
    RagMegaVariant[RagMegaVariant["PURPLE_BALL"] = 1] = "PURPLE_BALL";
    RagMegaVariant[RagMegaVariant["REBIRTH_PILLAR"] = 2] = "REBIRTH_PILLAR";
})(RagMegaVariant || (RagMegaVariant = {}));
/** For `EntityType.BIG_HORN` (411). */
export var BigHornVariant;
(function (BigHornVariant) {
    BigHornVariant[BigHornVariant["BIG_HORN"] = 0] = "BIG_HORN";
    BigHornVariant[BigHornVariant["SMALL_HOLE"] = 1] = "SMALL_HOLE";
    BigHornVariant[BigHornVariant["BIG_HOLE"] = 2] = "BIG_HOLE";
})(BigHornVariant || (BigHornVariant = {}));
/** For `EntityType.BLOOD_PUPPY` (802). */
export var BloodPuppyVariant;
(function (BloodPuppyVariant) {
    BloodPuppyVariant[BloodPuppyVariant["SMALL"] = 0] = "SMALL";
    BloodPuppyVariant[BloodPuppyVariant["LARGE"] = 1] = "LARGE";
})(BloodPuppyVariant || (BloodPuppyVariant = {}));
/** For `EntityType.SUB_HORF` (812). */
export var SubHorfVariant;
(function (SubHorfVariant) {
    SubHorfVariant[SubHorfVariant["SUB_HORF"] = 0] = "SUB_HORF";
    SubHorfVariant[SubHorfVariant["TAINTED_SUB_HORF"] = 1] = "TAINTED_SUB_HORF";
})(SubHorfVariant || (SubHorfVariant = {}));
/** For `EntityType.POLTY` (816). */
export var PoltyVariant;
(function (PoltyVariant) {
    PoltyVariant[PoltyVariant["POLTY"] = 0] = "POLTY";
    PoltyVariant[PoltyVariant["KINETI"] = 1] = "KINETI";
})(PoltyVariant || (PoltyVariant = {}));
/** For `EntityType.PREY` (817). */
export var PreyVariant;
(function (PreyVariant) {
    PreyVariant[PreyVariant["PREY"] = 0] = "PREY";
    PreyVariant[PreyVariant["MULLIGHOUL"] = 1] = "MULLIGHOUL";
})(PreyVariant || (PreyVariant = {}));
/** For `EntityType.ROCK_SPIDER` (818). */
export var RockSpiderVariant;
(function (RockSpiderVariant) {
    RockSpiderVariant[RockSpiderVariant["ROCK_SPIDER"] = 0] = "ROCK_SPIDER";
    RockSpiderVariant[RockSpiderVariant["TINTED_ROCK_SPIDER"] = 1] = "TINTED_ROCK_SPIDER";
    RockSpiderVariant[RockSpiderVariant["COAL_SPIDER"] = 2] = "COAL_SPIDER";
})(RockSpiderVariant || (RockSpiderVariant = {}));
/** For `EntityType.FLY_BOMB` (819). */
export var FlyBombVariant;
(function (FlyBombVariant) {
    FlyBombVariant[FlyBombVariant["FLY_BOMB"] = 0] = "FLY_BOMB";
    FlyBombVariant[FlyBombVariant["ETERNAL_FLY_BOMB"] = 1] = "ETERNAL_FLY_BOMB";
})(FlyBombVariant || (FlyBombVariant = {}));
/** For `EntityType.DANNY` (820). */
export var DannyVariant;
(function (DannyVariant) {
    DannyVariant[DannyVariant["DANNY"] = 0] = "DANNY";
    DannyVariant[DannyVariant["COAL_BOY"] = 1] = "COAL_BOY";
})(DannyVariant || (DannyVariant = {}));
/** For `EntityType.GYRO` (824). */
export var GyroVariant;
(function (GyroVariant) {
    GyroVariant[GyroVariant["GYRO"] = 0] = "GYRO";
    GyroVariant[GyroVariant["GRILLED_GYRO"] = 1] = "GRILLED_GYRO";
})(GyroVariant || (GyroVariant = {}));
/** For `EntityType.FACELESS` (827). */
export var FacelessVariant;
(function (FacelessVariant) {
    FacelessVariant[FacelessVariant["FACELESS"] = 0] = "FACELESS";
    FacelessVariant[FacelessVariant["TAINTED_FACELESS"] = 1] = "TAINTED_FACELESS";
})(FacelessVariant || (FacelessVariant = {}));
/** For `EntityType.MOLE` (829). */
export var MoleVariant;
(function (MoleVariant) {
    MoleVariant[MoleVariant["MOLE"] = 0] = "MOLE";
    MoleVariant[MoleVariant["TAINTED_MOLE"] = 1] = "TAINTED_MOLE";
})(MoleVariant || (MoleVariant = {}));
/** For `EntityType.BIG_BONY` (830). */
export var BigBonyVariant;
(function (BigBonyVariant) {
    BigBonyVariant[BigBonyVariant["BIG_BONY"] = 0] = "BIG_BONY";
    BigBonyVariant[BigBonyVariant["BIG_BONE"] = 10] = "BIG_BONE";
})(BigBonyVariant || (BigBonyVariant = {}));
/** For `EntityType.GUTTED_FATTY` (831). */
export var GuttyFattyVariant;
(function (GuttyFattyVariant) {
    GuttyFattyVariant[GuttyFattyVariant["GUTTED_FATTY"] = 0] = "GUTTED_FATTY";
    GuttyFattyVariant[GuttyFattyVariant["GUTTY_FATTY_EYE"] = 10] = "GUTTY_FATTY_EYE";
    GuttyFattyVariant[GuttyFattyVariant["FESTERING_GUTS"] = 20] = "FESTERING_GUTS";
})(GuttyFattyVariant || (GuttyFattyVariant = {}));
/** For `EntityType.EXORCIST` (832). */
export var ExorcistVariant;
(function (ExorcistVariant) {
    ExorcistVariant[ExorcistVariant["EXORCIST"] = 0] = "EXORCIST";
    ExorcistVariant[ExorcistVariant["FANATIC"] = 1] = "FANATIC";
})(ExorcistVariant || (ExorcistVariant = {}));
/** For `EntityType.WHIPPER` (834). */
export var WhipperVariant;
(function (WhipperVariant) {
    WhipperVariant[WhipperVariant["WHIPPER"] = 0] = "WHIPPER";
    WhipperVariant[WhipperVariant["SNAPPER"] = 1] = "SNAPPER";
    WhipperVariant[WhipperVariant["FLAGELLANT"] = 2] = "FLAGELLANT";
})(WhipperVariant || (WhipperVariant = {}));
/** For `EntityType.PEEPER_FATTY` (835). */
export var PeeperFattyVariant;
(function (PeeperFattyVariant) {
    PeeperFattyVariant[PeeperFattyVariant["PEEPING_FATTY"] = 0] = "PEEPING_FATTY";
    PeeperFattyVariant[PeeperFattyVariant["PEEPING_FATTY_EYE"] = 10] = "PEEPING_FATTY_EYE";
})(PeeperFattyVariant || (PeeperFattyVariant = {}));
/** For `EntityType.REVENANT` (841). */
export var RevenantVariant;
(function (RevenantVariant) {
    RevenantVariant[RevenantVariant["REVENANT"] = 0] = "REVENANT";
    RevenantVariant[RevenantVariant["QUAD_REVENANT"] = 1] = "QUAD_REVENANT";
})(RevenantVariant || (RevenantVariant = {}));
/** For `EntityType.CANARY` (843). */
export var CanaryVariant;
(function (CanaryVariant) {
    CanaryVariant[CanaryVariant["CANARY"] = 0] = "CANARY";
    CanaryVariant[CanaryVariant["FOREIGNER"] = 1] = "FOREIGNER";
})(CanaryVariant || (CanaryVariant = {}));
/** For `EntityType.GAPER_LVL_2` (850). */
export var Gaper2Variant;
(function (Gaper2Variant) {
    Gaper2Variant[Gaper2Variant["GAPER"] = 0] = "GAPER";
    Gaper2Variant[Gaper2Variant["HORF"] = 1] = "HORF";
    Gaper2Variant[Gaper2Variant["GUSHER"] = 2] = "GUSHER";
})(Gaper2Variant || (Gaper2Variant = {}));
/** For `EntityType.CHARGER_LVL_2` (855). */
export var Charger2Variant;
(function (Charger2Variant) {
    Charger2Variant[Charger2Variant["CHARGER"] = 0] = "CHARGER";
    Charger2Variant[Charger2Variant["ELLEECH"] = 1] = "ELLEECH";
})(Charger2Variant || (Charger2Variant = {}));
/** For `EntityType.EVIS` (865). */
export var EvisVariant;
(function (EvisVariant) {
    EvisVariant[EvisVariant["EVIS"] = 0] = "EVIS";
    EvisVariant[EvisVariant["EVIS_GUTS"] = 10] = "EVIS_GUTS";
})(EvisVariant || (EvisVariant = {}));
/** For `EntityType.DARK_ESAU` (866). */
export var DarkEsauVariant;
(function (DarkEsauVariant) {
    DarkEsauVariant[DarkEsauVariant["DARK_ESAU"] = 0] = "DARK_ESAU";
    DarkEsauVariant[DarkEsauVariant["PIT"] = 1] = "PIT";
})(DarkEsauVariant || (DarkEsauVariant = {}));
/** For `EntityType.DUMP` (876). */
export var DumpVariant;
(function (DumpVariant) {
    DumpVariant[DumpVariant["DUMP"] = 0] = "DUMP";
    DumpVariant[DumpVariant["DUMP_HEAD"] = 1] = "DUMP_HEAD";
})(DumpVariant || (DumpVariant = {}));
/** For `EntityType.NEEDLE` (881). */
export var NeedleVariant;
(function (NeedleVariant) {
    NeedleVariant[NeedleVariant["NEEDLE"] = 0] = "NEEDLE";
    NeedleVariant[NeedleVariant["PASTY"] = 1] = "PASTY";
})(NeedleVariant || (NeedleVariant = {}));
/** For `EntityType.CULTIST` (885). */
export var CultistVariant;
(function (CultistVariant) {
    CultistVariant[CultistVariant["CULTIST"] = 0] = "CULTIST";
    CultistVariant[CultistVariant["BLOOD_CULTIST"] = 1] = "BLOOD_CULTIST";
    CultistVariant[CultistVariant["BONE_TRAP"] = 10] = "BONE_TRAP";
})(CultistVariant || (CultistVariant = {}));
/** For `EntityType.VIS_FATTY` (886). */
export var VisFattyVariant;
(function (VisFattyVariant) {
    VisFattyVariant[VisFattyVariant["VIS_FATTY"] = 0] = "VIS_FATTY";
    VisFattyVariant[VisFattyVariant["FETAL_DEMON"] = 1] = "FETAL_DEMON";
})(VisFattyVariant || (VisFattyVariant = {}));
/** For `EntityType.GOAT` (891). */
export var GoatVariant;
(function (GoatVariant) {
    GoatVariant[GoatVariant["GOAT"] = 0] = "GOAT";
    GoatVariant[GoatVariant["BLACK_GOAT"] = 1] = "BLACK_GOAT";
})(GoatVariant || (GoatVariant = {}));
/** For `EntityType.VISAGE` (903). */
export var VisageVariant;
(function (VisageVariant) {
    VisageVariant[VisageVariant["VISAGE"] = 0] = "VISAGE";
    VisageVariant[VisageVariant["VISAGE_MASK"] = 1] = "VISAGE_MASK";
    VisageVariant[VisageVariant["VISAGE_CHAIN"] = 10] = "VISAGE_CHAIN";
    VisageVariant[VisageVariant["VISAGE_PLASMA"] = 20] = "VISAGE_PLASMA";
})(VisageVariant || (VisageVariant = {}));
/** For `EntityType.SIREN` (904). */
export var SirenVariant;
(function (SirenVariant) {
    SirenVariant[SirenVariant["SIREN"] = 0] = "SIREN";
    SirenVariant[SirenVariant["SIREN_SKULL"] = 1] = "SIREN_SKULL";
    SirenVariant[SirenVariant["SIREN_HELPER_PROJECTILE"] = 10] = "SIREN_HELPER_PROJECTILE";
})(SirenVariant || (SirenVariant = {}));
/** For `EntityType.SCOURGE` (909). */
export var ScourgeVariant;
(function (ScourgeVariant) {
    ScourgeVariant[ScourgeVariant["SCOURGE"] = 0] = "SCOURGE";
    ScourgeVariant[ScourgeVariant["SCOURGE_CHAIN"] = 10] = "SCOURGE_CHAIN";
})(ScourgeVariant || (ScourgeVariant = {}));
/** For `EntityType.CHIMERA` (910). */
export var ChimeraVariant;
(function (ChimeraVariant) {
    ChimeraVariant[ChimeraVariant["CHIMERA"] = 0] = "CHIMERA";
    ChimeraVariant[ChimeraVariant["CHIMERA_BODY"] = 1] = "CHIMERA_BODY";
    ChimeraVariant[ChimeraVariant["CHIMERA_HEAD"] = 2] = "CHIMERA_HEAD";
})(ChimeraVariant || (ChimeraVariant = {}));
/** For `EntityType.ROTGUT` (911). */
export var RotgutVariant;
(function (RotgutVariant) {
    RotgutVariant[RotgutVariant["PHASE_1_HEAD"] = 0] = "PHASE_1_HEAD";
    RotgutVariant[RotgutVariant["PHASE_2_MAGGOT"] = 1] = "PHASE_2_MAGGOT";
    RotgutVariant[RotgutVariant["PHASE_3_HEART"] = 2] = "PHASE_3_HEART";
})(RotgutVariant || (RotgutVariant = {}));
/** For `EntityType.MOTHER` (912). */
export var MotherVariant;
(function (MotherVariant) {
    /**
     * The body that is attached to the top of the screen in phase 1. During phase 2, it remains alive
     * but is inactive.
     */
    MotherVariant[MotherVariant["MOTHER_1"] = 0] = "MOTHER_1";
    /** The circular body that moves around in phase 2. */
    MotherVariant[MotherVariant["MOTHER_2"] = 10] = "MOTHER_2";
    MotherVariant[MotherVariant["BALL"] = 100] = "BALL";
})(MotherVariant || (MotherVariant = {}));
/** For `EntityType.SINGE` (915). */
export var SingeVariant;
(function (SingeVariant) {
    SingeVariant[SingeVariant["SINGE"] = 0] = "SINGE";
    SingeVariant[SingeVariant["SINGE_BALL"] = 1] = "SINGE_BALL";
})(SingeVariant || (SingeVariant = {}));
/** For `EntityType.RAGLICH` (919). */
export var RaglichVariant;
(function (RaglichVariant) {
    RaglichVariant[RaglichVariant["RAGLICH"] = 0] = "RAGLICH";
    RaglichVariant[RaglichVariant["RAGLICH_ARM"] = 1] = "RAGLICH_ARM";
})(RaglichVariant || (RaglichVariant = {}));
/** For `EntityType.CLUTCH` (921). */
export var ClutchVariant;
(function (ClutchVariant) {
    ClutchVariant[ClutchVariant["CLUTCH"] = 0] = "CLUTCH";
    ClutchVariant[ClutchVariant["CLUTCH_ORBITAL"] = 1] = "CLUTCH_ORBITAL";
})(ClutchVariant || (ClutchVariant = {}));
/** For `EntityType.DOGMA` (950). */
export var DogmaVariant;
(function (DogmaVariant) {
    DogmaVariant[DogmaVariant["DOGMA_PHASE_1"] = 0] = "DOGMA_PHASE_1";
    DogmaVariant[DogmaVariant["TV"] = 1] = "TV";
    DogmaVariant[DogmaVariant["ANGEL_PHASE_2"] = 2] = "ANGEL_PHASE_2";
    DogmaVariant[DogmaVariant["ANGEL_BABY_UNUSED"] = 10] = "ANGEL_BABY_UNUSED";
})(DogmaVariant || (DogmaVariant = {}));
/** For `EntityType.BEAST` (951). */
export var BeastVariant;
(function (BeastVariant) {
    BeastVariant[BeastVariant["BEAST"] = 0] = "BEAST";
    BeastVariant[BeastVariant["STALACTITE"] = 1] = "STALACTITE";
    BeastVariant[BeastVariant["ROCK_PROJECTILE"] = 2] = "ROCK_PROJECTILE";
    BeastVariant[BeastVariant["SOUL"] = 3] = "SOUL";
    BeastVariant[BeastVariant["ULTRA_FAMINE"] = 10] = "ULTRA_FAMINE";
    BeastVariant[BeastVariant["ULTRA_FAMINE_FLY"] = 11] = "ULTRA_FAMINE_FLY";
    BeastVariant[BeastVariant["ULTRA_PESTILENCE"] = 20] = "ULTRA_PESTILENCE";
    BeastVariant[BeastVariant["ULTRA_PESTILENCE_FLY"] = 21] = "ULTRA_PESTILENCE_FLY";
    BeastVariant[BeastVariant["ULTRA_PESTILENCE_MAGGOT"] = 22] = "ULTRA_PESTILENCE_MAGGOT";
    BeastVariant[BeastVariant["ULTRA_PESTILENCE_FLY_BALL"] = 23] = "ULTRA_PESTILENCE_FLY_BALL";
    BeastVariant[BeastVariant["ULTRA_WAR"] = 30] = "ULTRA_WAR";
    BeastVariant[BeastVariant["ULTRA_WAR_BOMB"] = 31] = "ULTRA_WAR_BOMB";
    BeastVariant[BeastVariant["ULTRA_DEATH"] = 40] = "ULTRA_DEATH";
    BeastVariant[BeastVariant["ULTRA_DEATH_SCYTHE"] = 41] = "ULTRA_DEATH_SCYTHE";
    BeastVariant[BeastVariant["ULTRA_DEATH_HEAD"] = 42] = "ULTRA_DEATH_HEAD";
    BeastVariant[BeastVariant["BACKGROUND_BEAST"] = 100] = "BACKGROUND_BEAST";
    BeastVariant[BeastVariant["BACKGROUND_FAMINE"] = 101] = "BACKGROUND_FAMINE";
    BeastVariant[BeastVariant["BACKGROUND_PESTILENCE"] = 102] = "BACKGROUND_PESTILENCE";
    BeastVariant[BeastVariant["BACKGROUND_WAR"] = 103] = "BACKGROUND_WAR";
    BeastVariant[BeastVariant["BACKGROUND_DEATH"] = 104] = "BACKGROUND_DEATH";
})(BeastVariant || (BeastVariant = {}));
/** For `EntityType.GENERIC_PROP` (960). */
export var GenericPropVariant;
(function (GenericPropVariant) {
    GenericPropVariant[GenericPropVariant["GENERIC_PROP"] = 0] = "GENERIC_PROP";
    GenericPropVariant[GenericPropVariant["MOMS_DRESSER"] = 1] = "MOMS_DRESSER";
    GenericPropVariant[GenericPropVariant["MOMS_VANITY"] = 2] = "MOMS_VANITY";
    GenericPropVariant[GenericPropVariant["COUCH"] = 3] = "COUCH";
    GenericPropVariant[GenericPropVariant["TV"] = 4] = "TV";
})(GenericPropVariant || (GenericPropVariant = {}));
/** For `EntityType.EFFECT` (1000). */
export var EffectVariant;
(function (EffectVariant) {
    EffectVariant[EffectVariant["EFFECT_NULL"] = 0] = "EFFECT_NULL";
    EffectVariant[EffectVariant["BOMB_EXPLOSION"] = 1] = "BOMB_EXPLOSION";
    EffectVariant[EffectVariant["BLOOD_EXPLOSION"] = 2] = "BLOOD_EXPLOSION";
    EffectVariant[EffectVariant["FLY_EXPLOSION"] = 3] = "FLY_EXPLOSION";
    EffectVariant[EffectVariant["ROCK_PARTICLE"] = 4] = "ROCK_PARTICLE";
    EffectVariant[EffectVariant["BLOOD_PARTICLE"] = 5] = "BLOOD_PARTICLE";
    EffectVariant[EffectVariant["DEVIL"] = 6] = "DEVIL";
    EffectVariant[EffectVariant["BLOOD_SPLAT"] = 7] = "BLOOD_SPLAT";
    EffectVariant[EffectVariant["LADDER"] = 8] = "LADDER";
    EffectVariant[EffectVariant["ANGEL"] = 9] = "ANGEL";
    EffectVariant[EffectVariant["BLUE_FLAME"] = 10] = "BLUE_FLAME";
    EffectVariant[EffectVariant["BULLET_POOF"] = 11] = "BULLET_POOF";
    EffectVariant[EffectVariant["TEAR_POOF_A"] = 12] = "TEAR_POOF_A";
    EffectVariant[EffectVariant["TEAR_POOF_B"] = 13] = "TEAR_POOF_B";
    EffectVariant[EffectVariant["RIPPLE_POOF"] = 14] = "RIPPLE_POOF";
    EffectVariant[EffectVariant["POOF_1"] = 15] = "POOF_1";
    EffectVariant[EffectVariant["POOF_2"] = 16] = "POOF_2";
    EffectVariant[EffectVariant["POOF_4"] = 17] = "POOF_4";
    EffectVariant[EffectVariant["BOMB_CRATER"] = 18] = "BOMB_CRATER";
    EffectVariant[EffectVariant["CRACK_THE_SKY"] = 19] = "CRACK_THE_SKY";
    EffectVariant[EffectVariant["SCYTHE_BREAK"] = 20] = "SCYTHE_BREAK";
    EffectVariant[EffectVariant["TINY_BUG"] = 21] = "TINY_BUG";
    EffectVariant[EffectVariant["CREEP_RED"] = 22] = "CREEP_RED";
    EffectVariant[EffectVariant["CREEP_GREEN"] = 23] = "CREEP_GREEN";
    EffectVariant[EffectVariant["CREEP_YELLOW"] = 24] = "CREEP_YELLOW";
    EffectVariant[EffectVariant["CREEP_WHITE"] = 25] = "CREEP_WHITE";
    EffectVariant[EffectVariant["CREEP_BLACK"] = 26] = "CREEP_BLACK";
    EffectVariant[EffectVariant["WOOD_PARTICLE"] = 27] = "WOOD_PARTICLE";
    EffectVariant[EffectVariant["MONSTROS_TOOTH"] = 28] = "MONSTROS_TOOTH";
    EffectVariant[EffectVariant["MOM_FOOT_STOMP"] = 29] = "MOM_FOOT_STOMP";
    EffectVariant[EffectVariant["TARGET"] = 30] = "TARGET";
    EffectVariant[EffectVariant["ROCKET"] = 31] = "ROCKET";
    EffectVariant[EffectVariant["PLAYER_CREEP_LEMON_MISHAP"] = 32] = "PLAYER_CREEP_LEMON_MISHAP";
    EffectVariant[EffectVariant["TINY_FLY"] = 33] = "TINY_FLY";
    EffectVariant[EffectVariant["FART"] = 34] = "FART";
    EffectVariant[EffectVariant["TOOTH_PARTICLE"] = 35] = "TOOTH_PARTICLE";
    EffectVariant[EffectVariant["XRAY_WALL"] = 36] = "XRAY_WALL";
    EffectVariant[EffectVariant["PLAYER_CREEP_HOLY_WATER"] = 37] = "PLAYER_CREEP_HOLY_WATER";
    EffectVariant[EffectVariant["SPIDER_EXPLOSION"] = 38] = "SPIDER_EXPLOSION";
    EffectVariant[EffectVariant["HEAVEN_LIGHT_DOOR"] = 39] = "HEAVEN_LIGHT_DOOR";
    EffectVariant[EffectVariant["STAR_FLASH"] = 40] = "STAR_FLASH";
    EffectVariant[EffectVariant["WATER_DROPLET"] = 41] = "WATER_DROPLET";
    EffectVariant[EffectVariant["BLOOD_GUSH"] = 42] = "BLOOD_GUSH";
    EffectVariant[EffectVariant["POOP_EXPLOSION"] = 43] = "POOP_EXPLOSION";
    EffectVariant[EffectVariant["PLAYER_CREEP_WHITE"] = 44] = "PLAYER_CREEP_WHITE";
    EffectVariant[EffectVariant["PLAYER_CREEP_BLACK"] = 45] = "PLAYER_CREEP_BLACK";
    EffectVariant[EffectVariant["PLAYER_CREEP_RED"] = 46] = "PLAYER_CREEP_RED";
    EffectVariant[EffectVariant["TRINITY_SHIELD"] = 47] = "TRINITY_SHIELD";
    EffectVariant[EffectVariant["BATTERY"] = 48] = "BATTERY";
    EffectVariant[EffectVariant["HEART"] = 49] = "HEART";
    EffectVariant[EffectVariant["LASER_IMPACT"] = 50] = "LASER_IMPACT";
    EffectVariant[EffectVariant["HOT_BOMB_FIRE"] = 51] = "HOT_BOMB_FIRE";
    EffectVariant[EffectVariant["RED_CANDLE_FLAME"] = 52] = "RED_CANDLE_FLAME";
    EffectVariant[EffectVariant["PLAYER_CREEP_GREEN"] = 53] = "PLAYER_CREEP_GREEN";
    EffectVariant[EffectVariant["PLAYER_CREEP_HOLY_WATER_TRAIL"] = 54] = "PLAYER_CREEP_HOLY_WATER_TRAIL";
    EffectVariant[EffectVariant["SPIKE"] = 55] = "SPIKE";
    EffectVariant[EffectVariant["CREEP_BROWN"] = 56] = "CREEP_BROWN";
    EffectVariant[EffectVariant["PULLING_EFFECT"] = 57] = "PULLING_EFFECT";
    EffectVariant[EffectVariant["POOP_PARTICLE"] = 58] = "POOP_PARTICLE";
    EffectVariant[EffectVariant["DUST_CLOUD"] = 59] = "DUST_CLOUD";
    EffectVariant[EffectVariant["BOOMERANG"] = 60] = "BOOMERANG";
    EffectVariant[EffectVariant["SHOCKWAVE"] = 61] = "SHOCKWAVE";
    EffectVariant[EffectVariant["ROCK_EXPLOSION"] = 62] = "ROCK_EXPLOSION";
    EffectVariant[EffectVariant["WORM"] = 63] = "WORM";
    EffectVariant[EffectVariant["BEETLE"] = 64] = "BEETLE";
    EffectVariant[EffectVariant["WISP"] = 65] = "WISP";
    EffectVariant[EffectVariant["EMBER_PARTICLE"] = 66] = "EMBER_PARTICLE";
    EffectVariant[EffectVariant["SHOCKWAVE_DIRECTIONAL"] = 67] = "SHOCKWAVE_DIRECTIONAL";
    EffectVariant[EffectVariant["WALL_BUG"] = 68] = "WALL_BUG";
    EffectVariant[EffectVariant["BUTTERFLY"] = 69] = "BUTTERFLY";
    EffectVariant[EffectVariant["BLOOD_DROP"] = 70] = "BLOOD_DROP";
    EffectVariant[EffectVariant["BRIMSTONE_SWIRL"] = 71] = "BRIMSTONE_SWIRL";
    EffectVariant[EffectVariant["CRACK_WAVE"] = 72] = "CRACK_WAVE";
    EffectVariant[EffectVariant["SHOCKWAVE_RANDOM"] = 73] = "SHOCKWAVE_RANDOM";
    EffectVariant[EffectVariant["CARPET"] = 74] = "CARPET";
    EffectVariant[EffectVariant["BAR_PARTICLE"] = 75] = "BAR_PARTICLE";
    EffectVariant[EffectVariant["DICE_FLOOR"] = 76] = "DICE_FLOOR";
    EffectVariant[EffectVariant["LARGE_BLOOD_EXPLOSION"] = 77] = "LARGE_BLOOD_EXPLOSION";
    EffectVariant[EffectVariant["PLAYER_CREEP_LEMON_PARTY"] = 78] = "PLAYER_CREEP_LEMON_PARTY";
    EffectVariant[EffectVariant["TEAR_POOF_SMALL"] = 79] = "TEAR_POOF_SMALL";
    EffectVariant[EffectVariant["TEAR_POOF_VERY_SMALL"] = 80] = "TEAR_POOF_VERY_SMALL";
    EffectVariant[EffectVariant["FRIEND_BALL"] = 81] = "FRIEND_BALL";
    EffectVariant[EffectVariant["WOMB_TELEPORT"] = 82] = "WOMB_TELEPORT";
    EffectVariant[EffectVariant["SPEAR_OF_DESTINY"] = 83] = "SPEAR_OF_DESTINY";
    EffectVariant[EffectVariant["EVIL_EYE"] = 84] = "EVIL_EYE";
    EffectVariant[EffectVariant["DIAMOND_PARTICLE"] = 85] = "DIAMOND_PARTICLE";
    EffectVariant[EffectVariant["NAIL_PARTICLE"] = 86] = "NAIL_PARTICLE";
    EffectVariant[EffectVariant["FALLING_EMBER"] = 87] = "FALLING_EMBER";
    EffectVariant[EffectVariant["DARK_BALL_SMOKE_PARTICLE"] = 88] = "DARK_BALL_SMOKE_PARTICLE";
    EffectVariant[EffectVariant["ULTRA_GREED_FOOTPRINT"] = 89] = "ULTRA_GREED_FOOTPRINT";
    EffectVariant[EffectVariant["PLAYER_CREEP_PUDDLE_MILK"] = 90] = "PLAYER_CREEP_PUDDLE_MILK";
    EffectVariant[EffectVariant["MOMS_HAND"] = 91] = "MOMS_HAND";
    EffectVariant[EffectVariant["PLAYER_CREEP_BLACK_POWDER"] = 92] = "PLAYER_CREEP_BLACK_POWDER";
    EffectVariant[EffectVariant["PENTAGRAM_BLACK_POWDER"] = 93] = "PENTAGRAM_BLACK_POWDER";
    EffectVariant[EffectVariant["CREEP_SLIPPERY_BROWN"] = 94] = "CREEP_SLIPPERY_BROWN";
    EffectVariant[EffectVariant["GOLD_PARTICLE"] = 95] = "GOLD_PARTICLE";
    EffectVariant[EffectVariant["HUSH_LASER"] = 96] = "HUSH_LASER";
    EffectVariant[EffectVariant["IMPACT"] = 97] = "IMPACT";
    EffectVariant[EffectVariant["COIN_PARTICLE"] = 98] = "COIN_PARTICLE";
    EffectVariant[EffectVariant["WATER_SPLASH"] = 99] = "WATER_SPLASH";
    EffectVariant[EffectVariant["HUSH_ASHES"] = 100] = "HUSH_ASHES";
    EffectVariant[EffectVariant["HUSH_LASER_UP"] = 101] = "HUSH_LASER_UP";
    EffectVariant[EffectVariant["BULLET_POOF_HUSH"] = 102] = "BULLET_POOF_HUSH";
    EffectVariant[EffectVariant["ULTRA_GREED_BLING"] = 103] = "ULTRA_GREED_BLING";
    EffectVariant[EffectVariant["FIREWORKS"] = 104] = "FIREWORKS";
    EffectVariant[EffectVariant["BROWN_CLOUD"] = 105] = "BROWN_CLOUD";
    EffectVariant[EffectVariant["FART_RING"] = 106] = "FART_RING";
    EffectVariant[EffectVariant["BLACK_HOLE"] = 107] = "BLACK_HOLE";
    EffectVariant[EffectVariant["MR_ME"] = 108] = "MR_ME";
    EffectVariant[EffectVariant["DEATH_SKULL"] = 109] = "DEATH_SKULL";
    EffectVariant[EffectVariant["ENEMY_BRIMSTONE_SWIRL"] = 110] = "ENEMY_BRIMSTONE_SWIRL";
    EffectVariant[EffectVariant["HAEMO_TRAIL"] = 111] = "HAEMO_TRAIL";
    EffectVariant[EffectVariant["HALLOWED_GROUND"] = 112] = "HALLOWED_GROUND";
    EffectVariant[EffectVariant["BRIMSTONE_BALL"] = 113] = "BRIMSTONE_BALL";
    EffectVariant[EffectVariant["FORGOTTEN_CHAIN"] = 114] = "FORGOTTEN_CHAIN";
    EffectVariant[EffectVariant["BROKEN_SHOVEL_SHADOW"] = 115] = "BROKEN_SHOVEL_SHADOW";
    EffectVariant[EffectVariant["DIRT_PATCH"] = 116] = "DIRT_PATCH";
    EffectVariant[EffectVariant["FORGOTTEN_SOUL"] = 117] = "FORGOTTEN_SOUL";
    EffectVariant[EffectVariant["SMALL_ROCKET"] = 118] = "SMALL_ROCKET";
    EffectVariant[EffectVariant["TIMER"] = 119] = "TIMER";
    EffectVariant[EffectVariant["SPAWNER"] = 120] = "SPAWNER";
    EffectVariant[EffectVariant["LIGHT"] = 121] = "LIGHT";
    EffectVariant[EffectVariant["BIG_HORN_HOLE_HELPER"] = 122] = "BIG_HORN_HOLE_HELPER";
    EffectVariant[EffectVariant["HALO"] = 123] = "HALO";
    EffectVariant[EffectVariant["TAR_BUBBLE"] = 124] = "TAR_BUBBLE";
    EffectVariant[EffectVariant["BIG_HORN_HAND"] = 125] = "BIG_HORN_HAND";
    EffectVariant[EffectVariant["TECH_DOT"] = 126] = "TECH_DOT";
    EffectVariant[EffectVariant["MAMA_MEGA_EXPLOSION"] = 127] = "MAMA_MEGA_EXPLOSION";
    EffectVariant[EffectVariant["OPTION_LINE"] = 128] = "OPTION_LINE";
    EffectVariant[EffectVariant["LEECH_EXPLOSION"] = 130] = "LEECH_EXPLOSION";
    EffectVariant[EffectVariant["MAGGOT_EXPLOSION"] = 131] = "MAGGOT_EXPLOSION";
    EffectVariant[EffectVariant["BIG_SPLASH"] = 132] = "BIG_SPLASH";
    EffectVariant[EffectVariant["WATER_RIPPLE"] = 133] = "WATER_RIPPLE";
    EffectVariant[EffectVariant["PEDESTAL_RIPPLE"] = 134] = "PEDESTAL_RIPPLE";
    EffectVariant[EffectVariant["RAIN_DROP"] = 135] = "RAIN_DROP";
    EffectVariant[EffectVariant["GRID_ENTITY_PROJECTILE_HELPER"] = 136] = "GRID_ENTITY_PROJECTILE_HELPER";
    EffectVariant[EffectVariant["WORMWOOD_HOLE"] = 137] = "WORMWOOD_HOLE";
    EffectVariant[EffectVariant["MIST"] = 138] = "MIST";
    EffectVariant[EffectVariant["TRAPDOOR_COVER"] = 139] = "TRAPDOOR_COVER";
    EffectVariant[EffectVariant["BACKDROP_DECORATION"] = 140] = "BACKDROP_DECORATION";
    EffectVariant[EffectVariant["SMOKE_CLOUD"] = 141] = "SMOKE_CLOUD";
    EffectVariant[EffectVariant["WHIRLPOOL"] = 142] = "WHIRLPOOL";
    EffectVariant[EffectVariant["FART_WAVE"] = 143] = "FART_WAVE";
    EffectVariant[EffectVariant["ENEMY_GHOST"] = 144] = "ENEMY_GHOST";
    EffectVariant[EffectVariant["ROCK_POOF"] = 145] = "ROCK_POOF";
    EffectVariant[EffectVariant["DIRT_PILE"] = 146] = "DIRT_PILE";
    EffectVariant[EffectVariant["FIRE_JET"] = 147] = "FIRE_JET";
    EffectVariant[EffectVariant["FIRE_WAVE"] = 148] = "FIRE_WAVE";
    EffectVariant[EffectVariant["BIG_ROCK_EXPLOSION"] = 149] = "BIG_ROCK_EXPLOSION";
    EffectVariant[EffectVariant["BIG_CRACK_WAVE"] = 150] = "BIG_CRACK_WAVE";
    EffectVariant[EffectVariant["BIG_ATTRACT"] = 151] = "BIG_ATTRACT";
    EffectVariant[EffectVariant["HORNFEL_ROOM_CONTROLLER"] = 152] = "HORNFEL_ROOM_CONTROLLER";
    EffectVariant[EffectVariant["OCCULT_TARGET"] = 153] = "OCCULT_TARGET";
    EffectVariant[EffectVariant["DOOR_OUTLINE"] = 154] = "DOOR_OUTLINE";
    EffectVariant[EffectVariant["CREEP_SLIPPERY_BROWN_GROWING"] = 155] = "CREEP_SLIPPERY_BROWN_GROWING";
    EffectVariant[EffectVariant["TALL_LADDER"] = 156] = "TALL_LADDER";
    EffectVariant[EffectVariant["WILLO_SPAWNER"] = 157] = "WILLO_SPAWNER";
    EffectVariant[EffectVariant["TADPOLE"] = 158] = "TADPOLE";
    EffectVariant[EffectVariant["LIL_GHOST"] = 159] = "LIL_GHOST";
    EffectVariant[EffectVariant["BISHOP_SHIELD"] = 160] = "BISHOP_SHIELD";
    EffectVariant[EffectVariant["PORTAL_TELEPORT"] = 161] = "PORTAL_TELEPORT";
    EffectVariant[EffectVariant["HERETIC_PENTAGRAM"] = 162] = "HERETIC_PENTAGRAM";
    EffectVariant[EffectVariant["CHAIN_GIB"] = 163] = "CHAIN_GIB";
    EffectVariant[EffectVariant["SIREN_RING"] = 164] = "SIREN_RING";
    EffectVariant[EffectVariant["CHARM_EFFECT"] = 165] = "CHARM_EFFECT";
    EffectVariant[EffectVariant["SPRITE_TRAIL"] = 166] = "SPRITE_TRAIL";
    EffectVariant[EffectVariant["CHAIN_LIGHTNING"] = 167] = "CHAIN_LIGHTNING";
    EffectVariant[EffectVariant["COLOSTOMIA_PUDDLE"] = 168] = "COLOSTOMIA_PUDDLE";
    EffectVariant[EffectVariant["CREEP_STATIC"] = 169] = "CREEP_STATIC";
    EffectVariant[EffectVariant["DOGMA_DEBRIS"] = 170] = "DOGMA_DEBRIS";
    EffectVariant[EffectVariant["DOGMA_BLACK_HOLE"] = 171] = "DOGMA_BLACK_HOLE";
    EffectVariant[EffectVariant["DOGMA_ORB"] = 172] = "DOGMA_ORB";
    EffectVariant[EffectVariant["CRACKED_ORB_POOF"] = 173] = "CRACKED_ORB_POOF";
    EffectVariant[EffectVariant["SHOP_SPIKES"] = 174] = "SHOP_SPIKES";
    EffectVariant[EffectVariant["KINETI_BEAM"] = 175] = "KINETI_BEAM";
    EffectVariant[EffectVariant["CLEAVER_SLASH"] = 176] = "CLEAVER_SLASH";
    EffectVariant[EffectVariant["REVERSE_EXPLOSION"] = 177] = "REVERSE_EXPLOSION";
    EffectVariant[EffectVariant["URN_OF_SOULS"] = 178] = "URN_OF_SOULS";
    EffectVariant[EffectVariant["ENEMY_SOUL"] = 179] = "ENEMY_SOUL";
    EffectVariant[EffectVariant["RIFT"] = 180] = "RIFT";
    EffectVariant[EffectVariant["LAVA_SPAWNER"] = 181] = "LAVA_SPAWNER";
    EffectVariant[EffectVariant["BIG_KNIFE"] = 182] = "BIG_KNIFE";
    EffectVariant[EffectVariant["MOTHER_SHOCKWAVE"] = 183] = "MOTHER_SHOCKWAVE";
    EffectVariant[EffectVariant["WORM_FRIEND_SNARE"] = 184] = "WORM_FRIEND_SNARE";
    EffectVariant[EffectVariant["REDEMPTION"] = 185] = "REDEMPTION";
    EffectVariant[EffectVariant["HUNGRY_SOUL"] = 186] = "HUNGRY_SOUL";
    EffectVariant[EffectVariant["EXPLOSION_WAVE"] = 187] = "EXPLOSION_WAVE";
    EffectVariant[EffectVariant["DIVINE_INTERVENTION"] = 188] = "DIVINE_INTERVENTION";
    EffectVariant[EffectVariant["PURGATORY"] = 189] = "PURGATORY";
    EffectVariant[EffectVariant["MOTHER_TRACER"] = 190] = "MOTHER_TRACER";
    EffectVariant[EffectVariant["PICKUP_GHOST"] = 191] = "PICKUP_GHOST";
    EffectVariant[EffectVariant["FISSURE_SPAWNER"] = 192] = "FISSURE_SPAWNER";
    EffectVariant[EffectVariant["ANIMA_CHAIN"] = 193] = "ANIMA_CHAIN";
    EffectVariant[EffectVariant["DARK_SNARE"] = 194] = "DARK_SNARE";
    EffectVariant[EffectVariant["CREEP_LIQUID_POOP"] = 195] = "CREEP_LIQUID_POOP";
    EffectVariant[EffectVariant["GROUND_GLOW"] = 196] = "GROUND_GLOW";
    EffectVariant[EffectVariant["DEAD_BIRD"] = 197] = "DEAD_BIRD";
    EffectVariant[EffectVariant["GENERIC_TRACER"] = 198] = "GENERIC_TRACER";
    EffectVariant[EffectVariant["ULTRA_DEATH_SCYTHE"] = 199] = "ULTRA_DEATH_SCYTHE";
})(EffectVariant || (EffectVariant = {}));
